# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/account/v1/account_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+strmprivacy/api/account/v1/account_v1.proto\x12\x1astrmprivacy.api.account.v1\x1a\x1fgoogle/api/field_behavior.proto\"2\n\x18GetAccountDetailsRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\"\xdb\x01\n\x19GetAccountDetailsResponse\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x1e\n\x11max_input_streams\x18\x02 \x01(\x05\x42\x03\xe0\x41\x02\x12\x13\n\x06handle\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x19\n\x0csubscription\x18\x04 \x01(\tB\x03\xe0\x41\x02\x12\x19\n\x0corganization\x18\x05 \x01(\tB\x03\xe0\x41\x02\x12\x1c\n\x0forganization_id\x18\x06 \x01(\tB\x03\xe0\x41\x02\x12\x1d\n\x10internal_user_id\x18\x07 \x01(\tB\x03\xe0\x41\x02\"\x1f\n\x19GetLegacyBillingIdRequest:\x02\x18\x01\"9\n\x1aGetLegacyBillingIdResponse\x12\x17\n\nbilling_id\x18\x01 \x01(\tB\x03\xe0\x41\x02:\x02\x18\x01\"I\n\x1a\x43reateAccountHandleRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x13\n\x06handle\x18\x02 \x01(\tB\x03\xe0\x41\x02\"2\n\x1b\x43reateAccountHandleResponse\x12\x13\n\x06handle\x18\x01 \x01(\tB\x03\xe0\x41\x02\"B\n\x19InitializeCheckoutRequest\x12\x14\n\x07plan_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"7\n\x1aInitializeCheckoutResponse\x12\x19\n\x0c\x63heckout_uri\x18\x01 \x01(\tB\x03\xe0\x41\x02\"R\n\x18GetCheckoutStatusRequest\x12\x14\n\x07user_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12 \n\x13\x63heckout_session_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\"+\n\x19GetCheckoutStatusResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\"U\n\x1bSetCheckoutCancelledRequest\x12\x14\n\x07user_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12 \n\x13\x63heckout_session_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\"\x1e\n\x1cSetCheckoutCancelledResponse\"7\n\x1fInitializeCustomerPortalRequest\x12\x14\n\x07user_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\"D\n InitializeCustomerPortalResponse\x12 \n\x13\x63ustomer_portal_uri\x18\x01 \x01(\tB\x03\xe0\x41\x02\x32\xcf\x07\n\x0e\x41\x63\x63ountService\x12\x80\x01\n\x11GetAccountDetails\x12\x34.strmprivacy.api.account.v1.GetAccountDetailsRequest\x1a\x35.strmprivacy.api.account.v1.GetAccountDetailsResponse\x12\x83\x01\n\x12GetLegacyBillingId\x12\x35.strmprivacy.api.account.v1.GetLegacyBillingIdRequest\x1a\x36.strmprivacy.api.account.v1.GetLegacyBillingIdResponse\x12\x86\x01\n\x13\x43reateAccountHandle\x12\x36.strmprivacy.api.account.v1.CreateAccountHandleRequest\x1a\x37.strmprivacy.api.account.v1.CreateAccountHandleResponse\x12\x83\x01\n\x12InitializeCheckout\x12\x35.strmprivacy.api.account.v1.InitializeCheckoutRequest\x1a\x36.strmprivacy.api.account.v1.InitializeCheckoutResponse\x12\x80\x01\n\x11GetCheckoutStatus\x12\x34.strmprivacy.api.account.v1.GetCheckoutStatusRequest\x1a\x35.strmprivacy.api.account.v1.GetCheckoutStatusResponse\x12\x95\x01\n\x18InitializeCustomerPortal\x12;.strmprivacy.api.account.v1.InitializeCustomerPortalRequest\x1a<.strmprivacy.api.account.v1.InitializeCustomerPortalResponse\x12\x89\x01\n\x14SetCheckoutCancelled\x12\x37.strmprivacy.api.account.v1.SetCheckoutCancelledRequest\x1a\x38.strmprivacy.api.account.v1.SetCheckoutCancelledResponseBf\n\x1dio.strmprivacy.api.account.v1P\x01ZCgithub.com/strmprivacy/api-definitions-go/v2/api/account/v1;accountb\x06proto3')



_GETACCOUNTDETAILSREQUEST = DESCRIPTOR.message_types_by_name['GetAccountDetailsRequest']
_GETACCOUNTDETAILSRESPONSE = DESCRIPTOR.message_types_by_name['GetAccountDetailsResponse']
_GETLEGACYBILLINGIDREQUEST = DESCRIPTOR.message_types_by_name['GetLegacyBillingIdRequest']
_GETLEGACYBILLINGIDRESPONSE = DESCRIPTOR.message_types_by_name['GetLegacyBillingIdResponse']
_CREATEACCOUNTHANDLEREQUEST = DESCRIPTOR.message_types_by_name['CreateAccountHandleRequest']
_CREATEACCOUNTHANDLERESPONSE = DESCRIPTOR.message_types_by_name['CreateAccountHandleResponse']
_INITIALIZECHECKOUTREQUEST = DESCRIPTOR.message_types_by_name['InitializeCheckoutRequest']
_INITIALIZECHECKOUTRESPONSE = DESCRIPTOR.message_types_by_name['InitializeCheckoutResponse']
_GETCHECKOUTSTATUSREQUEST = DESCRIPTOR.message_types_by_name['GetCheckoutStatusRequest']
_GETCHECKOUTSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['GetCheckoutStatusResponse']
_SETCHECKOUTCANCELLEDREQUEST = DESCRIPTOR.message_types_by_name['SetCheckoutCancelledRequest']
_SETCHECKOUTCANCELLEDRESPONSE = DESCRIPTOR.message_types_by_name['SetCheckoutCancelledResponse']
_INITIALIZECUSTOMERPORTALREQUEST = DESCRIPTOR.message_types_by_name['InitializeCustomerPortalRequest']
_INITIALIZECUSTOMERPORTALRESPONSE = DESCRIPTOR.message_types_by_name['InitializeCustomerPortalResponse']
GetAccountDetailsRequest = _reflection.GeneratedProtocolMessageType('GetAccountDetailsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTDETAILSREQUEST,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.GetAccountDetailsRequest)
  })
_sym_db.RegisterMessage(GetAccountDetailsRequest)

GetAccountDetailsResponse = _reflection.GeneratedProtocolMessageType('GetAccountDetailsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTDETAILSRESPONSE,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.GetAccountDetailsResponse)
  })
_sym_db.RegisterMessage(GetAccountDetailsResponse)

GetLegacyBillingIdRequest = _reflection.GeneratedProtocolMessageType('GetLegacyBillingIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLEGACYBILLINGIDREQUEST,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.GetLegacyBillingIdRequest)
  })
_sym_db.RegisterMessage(GetLegacyBillingIdRequest)

GetLegacyBillingIdResponse = _reflection.GeneratedProtocolMessageType('GetLegacyBillingIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLEGACYBILLINGIDRESPONSE,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.GetLegacyBillingIdResponse)
  })
_sym_db.RegisterMessage(GetLegacyBillingIdResponse)

CreateAccountHandleRequest = _reflection.GeneratedProtocolMessageType('CreateAccountHandleRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTHANDLEREQUEST,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.CreateAccountHandleRequest)
  })
_sym_db.RegisterMessage(CreateAccountHandleRequest)

CreateAccountHandleResponse = _reflection.GeneratedProtocolMessageType('CreateAccountHandleResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTHANDLERESPONSE,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.CreateAccountHandleResponse)
  })
_sym_db.RegisterMessage(CreateAccountHandleResponse)

InitializeCheckoutRequest = _reflection.GeneratedProtocolMessageType('InitializeCheckoutRequest', (_message.Message,), {
  'DESCRIPTOR' : _INITIALIZECHECKOUTREQUEST,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.InitializeCheckoutRequest)
  })
_sym_db.RegisterMessage(InitializeCheckoutRequest)

InitializeCheckoutResponse = _reflection.GeneratedProtocolMessageType('InitializeCheckoutResponse', (_message.Message,), {
  'DESCRIPTOR' : _INITIALIZECHECKOUTRESPONSE,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.InitializeCheckoutResponse)
  })
_sym_db.RegisterMessage(InitializeCheckoutResponse)

GetCheckoutStatusRequest = _reflection.GeneratedProtocolMessageType('GetCheckoutStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCHECKOUTSTATUSREQUEST,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.GetCheckoutStatusRequest)
  })
_sym_db.RegisterMessage(GetCheckoutStatusRequest)

GetCheckoutStatusResponse = _reflection.GeneratedProtocolMessageType('GetCheckoutStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCHECKOUTSTATUSRESPONSE,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.GetCheckoutStatusResponse)
  })
_sym_db.RegisterMessage(GetCheckoutStatusResponse)

SetCheckoutCancelledRequest = _reflection.GeneratedProtocolMessageType('SetCheckoutCancelledRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETCHECKOUTCANCELLEDREQUEST,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.SetCheckoutCancelledRequest)
  })
_sym_db.RegisterMessage(SetCheckoutCancelledRequest)

SetCheckoutCancelledResponse = _reflection.GeneratedProtocolMessageType('SetCheckoutCancelledResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETCHECKOUTCANCELLEDRESPONSE,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.SetCheckoutCancelledResponse)
  })
_sym_db.RegisterMessage(SetCheckoutCancelledResponse)

InitializeCustomerPortalRequest = _reflection.GeneratedProtocolMessageType('InitializeCustomerPortalRequest', (_message.Message,), {
  'DESCRIPTOR' : _INITIALIZECUSTOMERPORTALREQUEST,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.InitializeCustomerPortalRequest)
  })
_sym_db.RegisterMessage(InitializeCustomerPortalRequest)

InitializeCustomerPortalResponse = _reflection.GeneratedProtocolMessageType('InitializeCustomerPortalResponse', (_message.Message,), {
  'DESCRIPTOR' : _INITIALIZECUSTOMERPORTALRESPONSE,
  '__module__' : 'strmprivacy.api.account.v1.account_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.account.v1.InitializeCustomerPortalResponse)
  })
_sym_db.RegisterMessage(InitializeCustomerPortalResponse)

_ACCOUNTSERVICE = DESCRIPTOR.services_by_name['AccountService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035io.strmprivacy.api.account.v1P\001ZCgithub.com/strmprivacy/api-definitions-go/v2/api/account/v1;account'
  _GETACCOUNTDETAILSREQUEST.fields_by_name['billing_id']._options = None
  _GETACCOUNTDETAILSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['billing_id']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['max_input_streams']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['max_input_streams']._serialized_options = b'\340A\002'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['handle']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['handle']._serialized_options = b'\340A\001'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['subscription']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['subscription']._serialized_options = b'\340A\002'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['organization']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['organization']._serialized_options = b'\340A\002'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['organization_id']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['organization_id']._serialized_options = b'\340A\002'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['internal_user_id']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['internal_user_id']._serialized_options = b'\340A\002'
  _GETLEGACYBILLINGIDREQUEST._options = None
  _GETLEGACYBILLINGIDREQUEST._serialized_options = b'\030\001'
  _GETLEGACYBILLINGIDRESPONSE.fields_by_name['billing_id']._options = None
  _GETLEGACYBILLINGIDRESPONSE.fields_by_name['billing_id']._serialized_options = b'\340A\002'
  _GETLEGACYBILLINGIDRESPONSE._options = None
  _GETLEGACYBILLINGIDRESPONSE._serialized_options = b'\030\001'
  _CREATEACCOUNTHANDLEREQUEST.fields_by_name['billing_id']._options = None
  _CREATEACCOUNTHANDLEREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _CREATEACCOUNTHANDLEREQUEST.fields_by_name['handle']._options = None
  _CREATEACCOUNTHANDLEREQUEST.fields_by_name['handle']._serialized_options = b'\340A\002'
  _CREATEACCOUNTHANDLERESPONSE.fields_by_name['handle']._options = None
  _CREATEACCOUNTHANDLERESPONSE.fields_by_name['handle']._serialized_options = b'\340A\002'
  _INITIALIZECHECKOUTREQUEST.fields_by_name['plan_id']._options = None
  _INITIALIZECHECKOUTREQUEST.fields_by_name['plan_id']._serialized_options = b'\340A\002'
  _INITIALIZECHECKOUTRESPONSE.fields_by_name['checkout_uri']._options = None
  _INITIALIZECHECKOUTRESPONSE.fields_by_name['checkout_uri']._serialized_options = b'\340A\002'
  _GETCHECKOUTSTATUSREQUEST.fields_by_name['user_id']._options = None
  _GETCHECKOUTSTATUSREQUEST.fields_by_name['user_id']._serialized_options = b'\340A\002'
  _GETCHECKOUTSTATUSREQUEST.fields_by_name['checkout_session_id']._options = None
  _GETCHECKOUTSTATUSREQUEST.fields_by_name['checkout_session_id']._serialized_options = b'\340A\002'
  _SETCHECKOUTCANCELLEDREQUEST.fields_by_name['user_id']._options = None
  _SETCHECKOUTCANCELLEDREQUEST.fields_by_name['user_id']._serialized_options = b'\340A\002'
  _SETCHECKOUTCANCELLEDREQUEST.fields_by_name['checkout_session_id']._options = None
  _SETCHECKOUTCANCELLEDREQUEST.fields_by_name['checkout_session_id']._serialized_options = b'\340A\002'
  _INITIALIZECUSTOMERPORTALREQUEST.fields_by_name['user_id']._options = None
  _INITIALIZECUSTOMERPORTALREQUEST.fields_by_name['user_id']._serialized_options = b'\340A\002'
  _INITIALIZECUSTOMERPORTALRESPONSE.fields_by_name['customer_portal_uri']._options = None
  _INITIALIZECUSTOMERPORTALRESPONSE.fields_by_name['customer_portal_uri']._serialized_options = b'\340A\002'
  _GETACCOUNTDETAILSREQUEST._serialized_start=108
  _GETACCOUNTDETAILSREQUEST._serialized_end=158
  _GETACCOUNTDETAILSRESPONSE._serialized_start=161
  _GETACCOUNTDETAILSRESPONSE._serialized_end=380
  _GETLEGACYBILLINGIDREQUEST._serialized_start=382
  _GETLEGACYBILLINGIDREQUEST._serialized_end=413
  _GETLEGACYBILLINGIDRESPONSE._serialized_start=415
  _GETLEGACYBILLINGIDRESPONSE._serialized_end=472
  _CREATEACCOUNTHANDLEREQUEST._serialized_start=474
  _CREATEACCOUNTHANDLEREQUEST._serialized_end=547
  _CREATEACCOUNTHANDLERESPONSE._serialized_start=549
  _CREATEACCOUNTHANDLERESPONSE._serialized_end=599
  _INITIALIZECHECKOUTREQUEST._serialized_start=601
  _INITIALIZECHECKOUTREQUEST._serialized_end=667
  _INITIALIZECHECKOUTRESPONSE._serialized_start=669
  _INITIALIZECHECKOUTRESPONSE._serialized_end=724
  _GETCHECKOUTSTATUSREQUEST._serialized_start=726
  _GETCHECKOUTSTATUSREQUEST._serialized_end=808
  _GETCHECKOUTSTATUSRESPONSE._serialized_start=810
  _GETCHECKOUTSTATUSRESPONSE._serialized_end=853
  _SETCHECKOUTCANCELLEDREQUEST._serialized_start=855
  _SETCHECKOUTCANCELLEDREQUEST._serialized_end=940
  _SETCHECKOUTCANCELLEDRESPONSE._serialized_start=942
  _SETCHECKOUTCANCELLEDRESPONSE._serialized_end=972
  _INITIALIZECUSTOMERPORTALREQUEST._serialized_start=974
  _INITIALIZECUSTOMERPORTALREQUEST._serialized_end=1029
  _INITIALIZECUSTOMERPORTALRESPONSE._serialized_start=1031
  _INITIALIZECUSTOMERPORTALRESPONSE._serialized_end=1099
  _ACCOUNTSERVICE._serialized_start=1102
  _ACCOUNTSERVICE._serialized_end=2077
# @@protoc_insertion_point(module_scope)
