# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/projects/v1/projects_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-strmprivacy/api/projects/v1/projects_v1.proto\x12\x1bstrmprivacy.api.projects.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"\x15\n\x13ListProjectsRequest\"N\n\x14ListProjectsResponse\x12\x36\n\x08projects\x18\x01 \x03(\x0b\x32$.strmprivacy.api.entities.v1.Project\"M\n\x14\x43reateProjectRequest\x12\x35\n\x07project\x18\x01 \x01(\x0b\x32$.strmprivacy.api.entities.v1.Project\"N\n\x15\x43reateProjectResponse\x12\x35\n\x07project\x18\x01 \x01(\x0b\x32$.strmprivacy.api.entities.v1.Project\"*\n\x14\x44\x65leteProjectRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"\x17\n\x15\x44\x65leteProjectResponse2\xf6\x02\n\x0fProjectsService\x12s\n\x0cListProjects\x12\x30.strmprivacy.api.projects.v1.ListProjectsRequest\x1a\x31.strmprivacy.api.projects.v1.ListProjectsResponse\x12v\n\rCreateProject\x12\x31.strmprivacy.api.projects.v1.CreateProjectRequest\x1a\x32.strmprivacy.api.projects.v1.CreateProjectResponse\x12v\n\rDeleteProject\x12\x31.strmprivacy.api.projects.v1.DeleteProjectRequest\x1a\x32.strmprivacy.api.projects.v1.DeleteProjectResponseBi\n\x1eio.strmprivacy.api.projects.v1P\x01ZEgithub.com/strmprivacy/api-definitions-go/v2/api/projects/v1;projectsb\x06proto3')



_LISTPROJECTSREQUEST = DESCRIPTOR.message_types_by_name['ListProjectsRequest']
_LISTPROJECTSRESPONSE = DESCRIPTOR.message_types_by_name['ListProjectsResponse']
_CREATEPROJECTREQUEST = DESCRIPTOR.message_types_by_name['CreateProjectRequest']
_CREATEPROJECTRESPONSE = DESCRIPTOR.message_types_by_name['CreateProjectResponse']
_DELETEPROJECTREQUEST = DESCRIPTOR.message_types_by_name['DeleteProjectRequest']
_DELETEPROJECTRESPONSE = DESCRIPTOR.message_types_by_name['DeleteProjectResponse']
ListProjectsRequest = _reflection.GeneratedProtocolMessageType('ListProjectsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROJECTSREQUEST,
  '__module__' : 'strmprivacy.api.projects.v1.projects_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.projects.v1.ListProjectsRequest)
  })
_sym_db.RegisterMessage(ListProjectsRequest)

ListProjectsResponse = _reflection.GeneratedProtocolMessageType('ListProjectsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROJECTSRESPONSE,
  '__module__' : 'strmprivacy.api.projects.v1.projects_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.projects.v1.ListProjectsResponse)
  })
_sym_db.RegisterMessage(ListProjectsResponse)

CreateProjectRequest = _reflection.GeneratedProtocolMessageType('CreateProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROJECTREQUEST,
  '__module__' : 'strmprivacy.api.projects.v1.projects_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.projects.v1.CreateProjectRequest)
  })
_sym_db.RegisterMessage(CreateProjectRequest)

CreateProjectResponse = _reflection.GeneratedProtocolMessageType('CreateProjectResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROJECTRESPONSE,
  '__module__' : 'strmprivacy.api.projects.v1.projects_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.projects.v1.CreateProjectResponse)
  })
_sym_db.RegisterMessage(CreateProjectResponse)

DeleteProjectRequest = _reflection.GeneratedProtocolMessageType('DeleteProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPROJECTREQUEST,
  '__module__' : 'strmprivacy.api.projects.v1.projects_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.projects.v1.DeleteProjectRequest)
  })
_sym_db.RegisterMessage(DeleteProjectRequest)

DeleteProjectResponse = _reflection.GeneratedProtocolMessageType('DeleteProjectResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPROJECTRESPONSE,
  '__module__' : 'strmprivacy.api.projects.v1.projects_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.projects.v1.DeleteProjectResponse)
  })
_sym_db.RegisterMessage(DeleteProjectResponse)

_PROJECTSSERVICE = DESCRIPTOR.services_by_name['ProjectsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036io.strmprivacy.api.projects.v1P\001ZEgithub.com/strmprivacy/api-definitions-go/v2/api/projects/v1;projects'
  _LISTPROJECTSREQUEST._serialized_start=158
  _LISTPROJECTSREQUEST._serialized_end=179
  _LISTPROJECTSRESPONSE._serialized_start=181
  _LISTPROJECTSRESPONSE._serialized_end=259
  _CREATEPROJECTREQUEST._serialized_start=261
  _CREATEPROJECTREQUEST._serialized_end=338
  _CREATEPROJECTRESPONSE._serialized_start=340
  _CREATEPROJECTRESPONSE._serialized_end=418
  _DELETEPROJECTREQUEST._serialized_start=420
  _DELETEPROJECTREQUEST._serialized_end=462
  _DELETEPROJECTRESPONSE._serialized_start=464
  _DELETEPROJECTRESPONSE._serialized_end=487
  _PROJECTSSERVICE._serialized_start=490
  _PROJECTSSERVICE._serialized_end=864
# @@protoc_insertion_point(module_scope)
