# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/key_streams/v1/key_streams.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0strmprivacy/api/key_streams/v1/key_streams.proto\x12\x1estrmprivacy.api.key_streams.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"H\n\x15ListKeyStreamsRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x17\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x03\"U\n\x16ListKeyStreamsResponse\x12;\n\x0bkey_streams\x18\x01 \x03(\x0b\x32&.strmprivacy.api.entities.v1.KeyStream\"R\n\x13GetKeyStreamRequest\x12;\n\x03ref\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KeyStreamRefB\x03\xe0\x41\x02\"R\n\x14GetKeyStreamResponse\x12:\n\nkey_stream\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.KeyStream2\x8f\x02\n\x11KeyStreamsService\x12\x7f\n\x0eListKeyStreams\x12\x35.strmprivacy.api.key_streams.v1.ListKeyStreamsRequest\x1a\x36.strmprivacy.api.key_streams.v1.ListKeyStreamsResponse\x12y\n\x0cGetKeyStream\x12\x33.strmprivacy.api.key_streams.v1.GetKeyStreamRequest\x1a\x34.strmprivacy.api.key_streams.v1.GetKeyStreamResponseBr\n!io.strmprivacy.api.key_streams.v1P\x01ZKgithub.com/strmprivacy/api-definitions-go/v2/api/key_streams/v1;key_streamsb\x06proto3')



_LISTKEYSTREAMSREQUEST = DESCRIPTOR.message_types_by_name['ListKeyStreamsRequest']
_LISTKEYSTREAMSRESPONSE = DESCRIPTOR.message_types_by_name['ListKeyStreamsResponse']
_GETKEYSTREAMREQUEST = DESCRIPTOR.message_types_by_name['GetKeyStreamRequest']
_GETKEYSTREAMRESPONSE = DESCRIPTOR.message_types_by_name['GetKeyStreamResponse']
ListKeyStreamsRequest = _reflection.GeneratedProtocolMessageType('ListKeyStreamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTKEYSTREAMSREQUEST,
  '__module__' : 'strmprivacy.api.key_streams.v1.key_streams_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.key_streams.v1.ListKeyStreamsRequest)
  })
_sym_db.RegisterMessage(ListKeyStreamsRequest)

ListKeyStreamsResponse = _reflection.GeneratedProtocolMessageType('ListKeyStreamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTKEYSTREAMSRESPONSE,
  '__module__' : 'strmprivacy.api.key_streams.v1.key_streams_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.key_streams.v1.ListKeyStreamsResponse)
  })
_sym_db.RegisterMessage(ListKeyStreamsResponse)

GetKeyStreamRequest = _reflection.GeneratedProtocolMessageType('GetKeyStreamRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETKEYSTREAMREQUEST,
  '__module__' : 'strmprivacy.api.key_streams.v1.key_streams_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.key_streams.v1.GetKeyStreamRequest)
  })
_sym_db.RegisterMessage(GetKeyStreamRequest)

GetKeyStreamResponse = _reflection.GeneratedProtocolMessageType('GetKeyStreamResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETKEYSTREAMRESPONSE,
  '__module__' : 'strmprivacy.api.key_streams.v1.key_streams_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.key_streams.v1.GetKeyStreamResponse)
  })
_sym_db.RegisterMessage(GetKeyStreamResponse)

_KEYSTREAMSSERVICE = DESCRIPTOR.services_by_name['KeyStreamsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!io.strmprivacy.api.key_streams.v1P\001ZKgithub.com/strmprivacy/api-definitions-go/v2/api/key_streams/v1;key_streams'
  _LISTKEYSTREAMSREQUEST.fields_by_name['billing_id']._options = None
  _LISTKEYSTREAMSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _LISTKEYSTREAMSREQUEST.fields_by_name['project_id']._options = None
  _LISTKEYSTREAMSREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\003'
  _GETKEYSTREAMREQUEST.fields_by_name['ref']._options = None
  _GETKEYSTREAMREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _LISTKEYSTREAMSREQUEST._serialized_start=164
  _LISTKEYSTREAMSREQUEST._serialized_end=236
  _LISTKEYSTREAMSRESPONSE._serialized_start=238
  _LISTKEYSTREAMSRESPONSE._serialized_end=323
  _GETKEYSTREAMREQUEST._serialized_start=325
  _GETKEYSTREAMREQUEST._serialized_end=407
  _GETKEYSTREAMRESPONSE._serialized_start=409
  _GETKEYSTREAMRESPONSE._serialized_end=491
  _KEYSTREAMSSERVICE._serialized_start=494
  _KEYSTREAMSSERVICE._serialized_end=765
# @@protoc_insertion_point(module_scope)
