# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/consent_levels/v1/consent_levels_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9strmprivacy/api/consent_levels/v1/consent_levels_v1.proto\x12!strmprivacy.api.consent_levels.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"R\n\x1fListConsentLevelMappingsRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x17\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\"t\n ListConsentLevelMappingsResponse\x12P\n\x16\x63onsent_level_mappings\x18\x01 \x03(\x0b\x32\x30.strmprivacy.api.entities.v1.ConsentLevelMapping\"i\n DeleteConsentLevelMappingRequest\x12\x45\n\x03ref\x18\x01 \x01(\x0b\x32\x33.strmprivacy.api.entities.v1.ConsentLevelMappingRefB\x03\xe0\x41\x02\"#\n!DeleteConsentLevelMappingResponse\"s\n CreateConsentLevelMappingRequest\x12O\n\x15\x63onsent_level_mapping\x18\x01 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1.ConsentLevelMapping\"t\n!CreateConsentLevelMappingResponse\x12O\n\x15\x63onsent_level_mapping\x18\x01 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1.ConsentLevelMapping\"f\n\x1dGetConsentLevelMappingRequest\x12\x45\n\x03ref\x18\x01 \x01(\x0b\x32\x33.strmprivacy.api.entities.v1.ConsentLevelMappingRefB\x03\xe0\x41\x02\"q\n\x1eGetConsentLevelMappingResponse\x12O\n\x15\x63onsent_level_mapping\x18\x01 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1.ConsentLevelMapping2\xb5\x05\n\x1b\x43onsentLevelMappingsService\x12\xa3\x01\n\x18ListConsentLevelMappings\x12\x42.strmprivacy.api.consent_levels.v1.ListConsentLevelMappingsRequest\x1a\x43.strmprivacy.api.consent_levels.v1.ListConsentLevelMappingsResponse\x12\x9d\x01\n\x16GetConsentLevelMapping\x12@.strmprivacy.api.consent_levels.v1.GetConsentLevelMappingRequest\x1a\x41.strmprivacy.api.consent_levels.v1.GetConsentLevelMappingResponse\x12\xa6\x01\n\x19\x44\x65leteConsentLevelMapping\x12\x43.strmprivacy.api.consent_levels.v1.DeleteConsentLevelMappingRequest\x1a\x44.strmprivacy.api.consent_levels.v1.DeleteConsentLevelMappingResponse\x12\xa6\x01\n\x19\x43reateConsentLevelMapping\x12\x43.strmprivacy.api.consent_levels.v1.CreateConsentLevelMappingRequest\x1a\x44.strmprivacy.api.consent_levels.v1.CreateConsentLevelMappingResponseB{\n$io.strmprivacy.api.consent_levels.v1P\x01ZQgithub.com/strmprivacy/api-definitions-go/v2/api/consent_levels/v1;consent_levelsb\x06proto3')



_LISTCONSENTLEVELMAPPINGSREQUEST = DESCRIPTOR.message_types_by_name['ListConsentLevelMappingsRequest']
_LISTCONSENTLEVELMAPPINGSRESPONSE = DESCRIPTOR.message_types_by_name['ListConsentLevelMappingsResponse']
_DELETECONSENTLEVELMAPPINGREQUEST = DESCRIPTOR.message_types_by_name['DeleteConsentLevelMappingRequest']
_DELETECONSENTLEVELMAPPINGRESPONSE = DESCRIPTOR.message_types_by_name['DeleteConsentLevelMappingResponse']
_CREATECONSENTLEVELMAPPINGREQUEST = DESCRIPTOR.message_types_by_name['CreateConsentLevelMappingRequest']
_CREATECONSENTLEVELMAPPINGRESPONSE = DESCRIPTOR.message_types_by_name['CreateConsentLevelMappingResponse']
_GETCONSENTLEVELMAPPINGREQUEST = DESCRIPTOR.message_types_by_name['GetConsentLevelMappingRequest']
_GETCONSENTLEVELMAPPINGRESPONSE = DESCRIPTOR.message_types_by_name['GetConsentLevelMappingResponse']
ListConsentLevelMappingsRequest = _reflection.GeneratedProtocolMessageType('ListConsentLevelMappingsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONSENTLEVELMAPPINGSREQUEST,
  '__module__' : 'strmprivacy.api.consent_levels.v1.consent_levels_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.consent_levels.v1.ListConsentLevelMappingsRequest)
  })
_sym_db.RegisterMessage(ListConsentLevelMappingsRequest)

ListConsentLevelMappingsResponse = _reflection.GeneratedProtocolMessageType('ListConsentLevelMappingsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONSENTLEVELMAPPINGSRESPONSE,
  '__module__' : 'strmprivacy.api.consent_levels.v1.consent_levels_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.consent_levels.v1.ListConsentLevelMappingsResponse)
  })
_sym_db.RegisterMessage(ListConsentLevelMappingsResponse)

DeleteConsentLevelMappingRequest = _reflection.GeneratedProtocolMessageType('DeleteConsentLevelMappingRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECONSENTLEVELMAPPINGREQUEST,
  '__module__' : 'strmprivacy.api.consent_levels.v1.consent_levels_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.consent_levels.v1.DeleteConsentLevelMappingRequest)
  })
_sym_db.RegisterMessage(DeleteConsentLevelMappingRequest)

DeleteConsentLevelMappingResponse = _reflection.GeneratedProtocolMessageType('DeleteConsentLevelMappingResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETECONSENTLEVELMAPPINGRESPONSE,
  '__module__' : 'strmprivacy.api.consent_levels.v1.consent_levels_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.consent_levels.v1.DeleteConsentLevelMappingResponse)
  })
_sym_db.RegisterMessage(DeleteConsentLevelMappingResponse)

CreateConsentLevelMappingRequest = _reflection.GeneratedProtocolMessageType('CreateConsentLevelMappingRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONSENTLEVELMAPPINGREQUEST,
  '__module__' : 'strmprivacy.api.consent_levels.v1.consent_levels_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.consent_levels.v1.CreateConsentLevelMappingRequest)
  })
_sym_db.RegisterMessage(CreateConsentLevelMappingRequest)

CreateConsentLevelMappingResponse = _reflection.GeneratedProtocolMessageType('CreateConsentLevelMappingResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONSENTLEVELMAPPINGRESPONSE,
  '__module__' : 'strmprivacy.api.consent_levels.v1.consent_levels_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.consent_levels.v1.CreateConsentLevelMappingResponse)
  })
_sym_db.RegisterMessage(CreateConsentLevelMappingResponse)

GetConsentLevelMappingRequest = _reflection.GeneratedProtocolMessageType('GetConsentLevelMappingRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONSENTLEVELMAPPINGREQUEST,
  '__module__' : 'strmprivacy.api.consent_levels.v1.consent_levels_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.consent_levels.v1.GetConsentLevelMappingRequest)
  })
_sym_db.RegisterMessage(GetConsentLevelMappingRequest)

GetConsentLevelMappingResponse = _reflection.GeneratedProtocolMessageType('GetConsentLevelMappingResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCONSENTLEVELMAPPINGRESPONSE,
  '__module__' : 'strmprivacy.api.consent_levels.v1.consent_levels_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.consent_levels.v1.GetConsentLevelMappingResponse)
  })
_sym_db.RegisterMessage(GetConsentLevelMappingResponse)

_CONSENTLEVELMAPPINGSSERVICE = DESCRIPTOR.services_by_name['ConsentLevelMappingsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$io.strmprivacy.api.consent_levels.v1P\001ZQgithub.com/strmprivacy/api-definitions-go/v2/api/consent_levels/v1;consent_levels'
  _LISTCONSENTLEVELMAPPINGSREQUEST.fields_by_name['billing_id']._options = None
  _LISTCONSENTLEVELMAPPINGSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _LISTCONSENTLEVELMAPPINGSREQUEST.fields_by_name['project_id']._options = None
  _LISTCONSENTLEVELMAPPINGSREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _DELETECONSENTLEVELMAPPINGREQUEST.fields_by_name['ref']._options = None
  _DELETECONSENTLEVELMAPPINGREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _GETCONSENTLEVELMAPPINGREQUEST.fields_by_name['ref']._options = None
  _GETCONSENTLEVELMAPPINGREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _LISTCONSENTLEVELMAPPINGSREQUEST._serialized_start=176
  _LISTCONSENTLEVELMAPPINGSREQUEST._serialized_end=258
  _LISTCONSENTLEVELMAPPINGSRESPONSE._serialized_start=260
  _LISTCONSENTLEVELMAPPINGSRESPONSE._serialized_end=376
  _DELETECONSENTLEVELMAPPINGREQUEST._serialized_start=378
  _DELETECONSENTLEVELMAPPINGREQUEST._serialized_end=483
  _DELETECONSENTLEVELMAPPINGRESPONSE._serialized_start=485
  _DELETECONSENTLEVELMAPPINGRESPONSE._serialized_end=520
  _CREATECONSENTLEVELMAPPINGREQUEST._serialized_start=522
  _CREATECONSENTLEVELMAPPINGREQUEST._serialized_end=637
  _CREATECONSENTLEVELMAPPINGRESPONSE._serialized_start=639
  _CREATECONSENTLEVELMAPPINGRESPONSE._serialized_end=755
  _GETCONSENTLEVELMAPPINGREQUEST._serialized_start=757
  _GETCONSENTLEVELMAPPINGREQUEST._serialized_end=859
  _GETCONSENTLEVELMAPPINGRESPONSE._serialized_start=861
  _GETCONSENTLEVELMAPPINGRESPONSE._serialized_end=974
  _CONSENTLEVELMAPPINGSSERVICE._serialized_start=977
  _CONSENTLEVELMAPPINGSSERVICE._serialized_end=1670
# @@protoc_insertion_point(module_scope)
