# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/kafka_clusters/v1/kafka_clusters_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9strmprivacy/api/kafka_clusters/v1/kafka_clusters_v1.proto\x12!strmprivacy.api.kafka_clusters.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"L\n\x18ListKafkaClustersRequest\x12\x17\n\nbilling_id\x18\x01 \x01(\tB\x03\xe0\x41\x03\x12\x17\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x03\"^\n\x19ListKafkaClustersResponse\x12\x41\n\x0ekafka_clusters\x18\x01 \x03(\x0b\x32).strmprivacy.api.entities.v1.KafkaCluster\"\x8d\x01\n\x19\x44\x65leteKafkaClusterRequest\x12\x17\n\nbilling_id\x18\x01 \x01(\tB\x03\xe0\x41\x03\x12>\n\x03ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRefB\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x03\"\x1c\n\x1a\x44\x65leteKafkaClusterResponse\"]\n\x19\x43reateKafkaClusterRequest\x12@\n\rkafka_cluster\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KafkaCluster\"^\n\x1a\x43reateKafkaClusterResponse\x12@\n\rkafka_cluster\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KafkaCluster\"\x8a\x01\n\x16GetKafkaClusterRequest\x12\x17\n\nbilling_id\x18\x01 \x01(\tB\x03\xe0\x41\x03\x12>\n\x03ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRefB\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x03\"[\n\x17GetKafkaClusterResponse\x12@\n\rkafka_cluster\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KafkaCluster2\xda\x04\n\x14KafkaClustersService\x12\x8e\x01\n\x11ListKafkaClusters\x12;.strmprivacy.api.kafka_clusters.v1.ListKafkaClustersRequest\x1a<.strmprivacy.api.kafka_clusters.v1.ListKafkaClustersResponse\x12\x88\x01\n\x0fGetKafkaCluster\x12\x39.strmprivacy.api.kafka_clusters.v1.GetKafkaClusterRequest\x1a:.strmprivacy.api.kafka_clusters.v1.GetKafkaClusterResponse\x12\x91\x01\n\x12\x44\x65leteKafkaCluster\x12<.strmprivacy.api.kafka_clusters.v1.DeleteKafkaClusterRequest\x1a=.strmprivacy.api.kafka_clusters.v1.DeleteKafkaClusterResponse\x12\x91\x01\n\x12\x43reateKafkaCluster\x12<.strmprivacy.api.kafka_clusters.v1.CreateKafkaClusterRequest\x1a=.strmprivacy.api.kafka_clusters.v1.CreateKafkaClusterResponseB{\n$io.strmprivacy.api.kafka_clusters.v1P\x01ZQgithub.com/strmprivacy/api-definitions-go/v2/api/kafka_clusters/v1;kafka_clustersb\x06proto3')



_LISTKAFKACLUSTERSREQUEST = DESCRIPTOR.message_types_by_name['ListKafkaClustersRequest']
_LISTKAFKACLUSTERSRESPONSE = DESCRIPTOR.message_types_by_name['ListKafkaClustersResponse']
_DELETEKAFKACLUSTERREQUEST = DESCRIPTOR.message_types_by_name['DeleteKafkaClusterRequest']
_DELETEKAFKACLUSTERRESPONSE = DESCRIPTOR.message_types_by_name['DeleteKafkaClusterResponse']
_CREATEKAFKACLUSTERREQUEST = DESCRIPTOR.message_types_by_name['CreateKafkaClusterRequest']
_CREATEKAFKACLUSTERRESPONSE = DESCRIPTOR.message_types_by_name['CreateKafkaClusterResponse']
_GETKAFKACLUSTERREQUEST = DESCRIPTOR.message_types_by_name['GetKafkaClusterRequest']
_GETKAFKACLUSTERRESPONSE = DESCRIPTOR.message_types_by_name['GetKafkaClusterResponse']
ListKafkaClustersRequest = _reflection.GeneratedProtocolMessageType('ListKafkaClustersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTKAFKACLUSTERSREQUEST,
  '__module__' : 'strmprivacy.api.kafka_clusters.v1.kafka_clusters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_clusters.v1.ListKafkaClustersRequest)
  })
_sym_db.RegisterMessage(ListKafkaClustersRequest)

ListKafkaClustersResponse = _reflection.GeneratedProtocolMessageType('ListKafkaClustersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTKAFKACLUSTERSRESPONSE,
  '__module__' : 'strmprivacy.api.kafka_clusters.v1.kafka_clusters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_clusters.v1.ListKafkaClustersResponse)
  })
_sym_db.RegisterMessage(ListKafkaClustersResponse)

DeleteKafkaClusterRequest = _reflection.GeneratedProtocolMessageType('DeleteKafkaClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEKAFKACLUSTERREQUEST,
  '__module__' : 'strmprivacy.api.kafka_clusters.v1.kafka_clusters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_clusters.v1.DeleteKafkaClusterRequest)
  })
_sym_db.RegisterMessage(DeleteKafkaClusterRequest)

DeleteKafkaClusterResponse = _reflection.GeneratedProtocolMessageType('DeleteKafkaClusterResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEKAFKACLUSTERRESPONSE,
  '__module__' : 'strmprivacy.api.kafka_clusters.v1.kafka_clusters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_clusters.v1.DeleteKafkaClusterResponse)
  })
_sym_db.RegisterMessage(DeleteKafkaClusterResponse)

CreateKafkaClusterRequest = _reflection.GeneratedProtocolMessageType('CreateKafkaClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEKAFKACLUSTERREQUEST,
  '__module__' : 'strmprivacy.api.kafka_clusters.v1.kafka_clusters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_clusters.v1.CreateKafkaClusterRequest)
  })
_sym_db.RegisterMessage(CreateKafkaClusterRequest)

CreateKafkaClusterResponse = _reflection.GeneratedProtocolMessageType('CreateKafkaClusterResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEKAFKACLUSTERRESPONSE,
  '__module__' : 'strmprivacy.api.kafka_clusters.v1.kafka_clusters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_clusters.v1.CreateKafkaClusterResponse)
  })
_sym_db.RegisterMessage(CreateKafkaClusterResponse)

GetKafkaClusterRequest = _reflection.GeneratedProtocolMessageType('GetKafkaClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETKAFKACLUSTERREQUEST,
  '__module__' : 'strmprivacy.api.kafka_clusters.v1.kafka_clusters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_clusters.v1.GetKafkaClusterRequest)
  })
_sym_db.RegisterMessage(GetKafkaClusterRequest)

GetKafkaClusterResponse = _reflection.GeneratedProtocolMessageType('GetKafkaClusterResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETKAFKACLUSTERRESPONSE,
  '__module__' : 'strmprivacy.api.kafka_clusters.v1.kafka_clusters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_clusters.v1.GetKafkaClusterResponse)
  })
_sym_db.RegisterMessage(GetKafkaClusterResponse)

_KAFKACLUSTERSSERVICE = DESCRIPTOR.services_by_name['KafkaClustersService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$io.strmprivacy.api.kafka_clusters.v1P\001ZQgithub.com/strmprivacy/api-definitions-go/v2/api/kafka_clusters/v1;kafka_clusters'
  _LISTKAFKACLUSTERSREQUEST.fields_by_name['billing_id']._options = None
  _LISTKAFKACLUSTERSREQUEST.fields_by_name['billing_id']._serialized_options = b'\340A\003'
  _LISTKAFKACLUSTERSREQUEST.fields_by_name['project_id']._options = None
  _LISTKAFKACLUSTERSREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\003'
  _DELETEKAFKACLUSTERREQUEST.fields_by_name['billing_id']._options = None
  _DELETEKAFKACLUSTERREQUEST.fields_by_name['billing_id']._serialized_options = b'\340A\003'
  _DELETEKAFKACLUSTERREQUEST.fields_by_name['ref']._options = None
  _DELETEKAFKACLUSTERREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _DELETEKAFKACLUSTERREQUEST.fields_by_name['project_id']._options = None
  _DELETEKAFKACLUSTERREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\003'
  _GETKAFKACLUSTERREQUEST.fields_by_name['billing_id']._options = None
  _GETKAFKACLUSTERREQUEST.fields_by_name['billing_id']._serialized_options = b'\340A\003'
  _GETKAFKACLUSTERREQUEST.fields_by_name['ref']._options = None
  _GETKAFKACLUSTERREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _GETKAFKACLUSTERREQUEST.fields_by_name['project_id']._options = None
  _GETKAFKACLUSTERREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\003'
  _LISTKAFKACLUSTERSREQUEST._serialized_start=176
  _LISTKAFKACLUSTERSREQUEST._serialized_end=252
  _LISTKAFKACLUSTERSRESPONSE._serialized_start=254
  _LISTKAFKACLUSTERSRESPONSE._serialized_end=348
  _DELETEKAFKACLUSTERREQUEST._serialized_start=351
  _DELETEKAFKACLUSTERREQUEST._serialized_end=492
  _DELETEKAFKACLUSTERRESPONSE._serialized_start=494
  _DELETEKAFKACLUSTERRESPONSE._serialized_end=522
  _CREATEKAFKACLUSTERREQUEST._serialized_start=524
  _CREATEKAFKACLUSTERREQUEST._serialized_end=617
  _CREATEKAFKACLUSTERRESPONSE._serialized_start=619
  _CREATEKAFKACLUSTERRESPONSE._serialized_end=713
  _GETKAFKACLUSTERREQUEST._serialized_start=716
  _GETKAFKACLUSTERREQUEST._serialized_end=854
  _GETKAFKACLUSTERRESPONSE._serialized_start=856
  _GETKAFKACLUSTERRESPONSE._serialized_end=947
  _KAFKACLUSTERSSERVICE._serialized_start=950
  _KAFKACLUSTERSSERVICE._serialized_end=1552
# @@protoc_insertion_point(module_scope)
