# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/data_contracts/v1/data_contracts_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9strmprivacy/api/data_contracts/v1/data_contracts_v1.proto\x12!strmprivacy.api.data_contracts.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"\xbf\x02\n\x18ListDataContractsRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x13\n\x06\x66ilter\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06handle\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x11\n\x04name\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12M\n\x0epublic_private\x18\x05 \x01(\x0e\x32\x30.strmprivacy.api.entities.v1.FilterPublicPrivateB\x03\xe0\x41\x01\x12\x37\n\x06labels\x18\x07 \x03(\x0b\x32\".strmprivacy.api.entities.v1.LabelB\x03\xe0\x41\x01\x12\x14\n\x07\x64omains\x18\x08 \x03(\tB\x03\xe0\x41\x01\x12\x17\n\nindustries\x18\t \x03(\tB\x03\xe0\x41\x01\x12\x17\n\nproject_id\x18\n \x01(\tB\x03\xe0\x41\x02\"^\n\x19ListDataContractsResponse\x12\x41\n\x0e\x64\x61ta_contracts\x18\x01 \x03(\x0b\x32).strmprivacy.api.entities.v1.DataContract\"w\n\x16GetDataContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x39\n\x03ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.DataContractRef\x12\n\n\x02id\x18\x03 \x01(\t\"r\n\x17GetDataContractResponse\x12@\n\rdata_contract\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.DataContract\x12\x15\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x02\"\x89\x01\n\x19\x43reateDataContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12@\n\rdata_contract\x18\x02 \x01(\x0b\x32).strmprivacy.api.entities.v1.DataContract\x12\x12\n\nproject_id\x18\x03 \x01(\t\"u\n\x1a\x43reateDataContractResponse\x12@\n\rdata_contract\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.DataContract\x12\x15\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x03\"\xc7\x01\n\x19UpdateDataContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x45\n\rdata_contract\x18\x02 \x01(\x0b\x32).strmprivacy.api.entities.v1.DataContractB\x03\xe0\x41\x02\x12\x15\n\x08\x63hecksum\x18\x03 \x01(\tB\x03\xe0\x41\x02\x12\x34\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02\"u\n\x1aUpdateDataContractResponse\x12@\n\rdata_contract\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.DataContract\x12\x15\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x03\"D\n\x19ReviewDataContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x0f\n\x02id\x18\x02 \x01(\tB\x03\xe0\x41\x02\"\x1c\n\x1aReviewDataContractResponse\"F\n\x1b\x41\x63tivateDataContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x0f\n\x02id\x18\x02 \x01(\tB\x03\xe0\x41\x02\"\x1e\n\x1c\x41\x63tivateDataContractResponse\"D\n\x19\x44\x65leteDataContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x0f\n\x02id\x18\x02 \x01(\tB\x03\xe0\x41\x02\"\x1c\n\x1a\x44\x65leteDataContractResponse\"E\n\x1a\x41rchiveDataContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x0f\n\x02id\x18\x02 \x01(\tB\x03\xe0\x41\x02\"\x1d\n\x1b\x41rchiveDataContractResponse\"\x84\x01\n(ValidateDataContractsMaskedFieldsRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12@\n\rmasked_fields\x18\x02 \x01(\x0b\x32).strmprivacy.api.entities.v1.MaskedFields\"\xc2\x03\n)ValidateDataContractsMaskedFieldsResponse\x12\x62\n\x06\x65rrors\x18\x01 \x03(\x0b\x32R.strmprivacy.api.data_contracts.v1.ValidateDataContractsMaskedFieldsResponse.Error\x1a\xb0\x02\n\x05\x45rror\x12\x0f\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12L\n\x11\x64\x61ta_contract_ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.DataContractRefB\x03\xe0\x41\x02\x12\x0f\n\x07message\x18\x03 \x01(\t\x12m\n\x06\x65rrors\x18\x04 \x03(\x0b\x32].strmprivacy.api.data_contracts.v1.ValidateDataContractsMaskedFieldsResponse.Error.FieldError\x1aH\n\nFieldError\x12\x15\n\rfield_pattern\x18\x01 \x01(\t\x12\x12\n\nfield_type\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"b\n GetDataContractSchemaCodeRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x0f\n\x02id\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x15\n\x08language\x18\x03 \x01(\tB\x03\xe0\x41\x02\"V\n!GetDataContractSchemaCodeResponse\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x11\n\tdata_size\x18\x02 \x01(\x03\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"\x81\x01\n&GetDataContractSchemaDefinitionRequest\x12\x14\n\x0c\x63onfluent_id\x18\x01 \x01(\x05\x12\x41\n\x0b\x63luster_ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRef\"=\n\'GetDataContractSchemaDefinitionResponse\x12\x12\n\ndefinition\x18\x01 \x01(\t2\xd8\r\n\x14\x44\x61taContractsService\x12\x8e\x01\n\x11ListDataContracts\x12;.strmprivacy.api.data_contracts.v1.ListDataContractsRequest\x1a<.strmprivacy.api.data_contracts.v1.ListDataContractsResponse\x12\x88\x01\n\x0fGetDataContract\x12\x39.strmprivacy.api.data_contracts.v1.GetDataContractRequest\x1a:.strmprivacy.api.data_contracts.v1.GetDataContractResponse\x12\x91\x01\n\x12\x43reateDataContract\x12<.strmprivacy.api.data_contracts.v1.CreateDataContractRequest\x1a=.strmprivacy.api.data_contracts.v1.CreateDataContractResponse\x12\x91\x01\n\x12UpdateDataContract\x12<.strmprivacy.api.data_contracts.v1.UpdateDataContractRequest\x1a=.strmprivacy.api.data_contracts.v1.UpdateDataContractResponse\x12\x91\x01\n\x12ReviewDataContract\x12<.strmprivacy.api.data_contracts.v1.ReviewDataContractRequest\x1a=.strmprivacy.api.data_contracts.v1.ReviewDataContractResponse\x12\x97\x01\n\x14\x41\x63tivateDataContract\x12>.strmprivacy.api.data_contracts.v1.ActivateDataContractRequest\x1a?.strmprivacy.api.data_contracts.v1.ActivateDataContractResponse\x12\x91\x01\n\x12\x44\x65leteDataContract\x12<.strmprivacy.api.data_contracts.v1.DeleteDataContractRequest\x1a=.strmprivacy.api.data_contracts.v1.DeleteDataContractResponse\x12\x94\x01\n\x13\x41rchiveDataContract\x12=.strmprivacy.api.data_contracts.v1.ArchiveDataContractRequest\x1a>.strmprivacy.api.data_contracts.v1.ArchiveDataContractResponse\x12\xa6\x01\n\x19GetDataContractSchemaCode\x12\x43.strmprivacy.api.data_contracts.v1.GetDataContractSchemaCodeRequest\x1a\x44.strmprivacy.api.data_contracts.v1.GetDataContractSchemaCodeResponse\x12\xb8\x01\n\x1fGetDataContractSchemaDefinition\x12I.strmprivacy.api.data_contracts.v1.GetDataContractSchemaDefinitionRequest\x1aJ.strmprivacy.api.data_contracts.v1.GetDataContractSchemaDefinitionResponse\x12\xbe\x01\n!ValidateDataContractsMaskedFields\x12K.strmprivacy.api.data_contracts.v1.ValidateDataContractsMaskedFieldsRequest\x1aL.strmprivacy.api.data_contracts.v1.ValidateDataContractsMaskedFieldsResponseB{\n$io.strmprivacy.api.data_contracts.v1P\x01ZQgithub.com/strmprivacy/api-definitions-go/v2/api/data_contracts/v1;data_contractsb\x06proto3')



_LISTDATACONTRACTSREQUEST = DESCRIPTOR.message_types_by_name['ListDataContractsRequest']
_LISTDATACONTRACTSRESPONSE = DESCRIPTOR.message_types_by_name['ListDataContractsResponse']
_GETDATACONTRACTREQUEST = DESCRIPTOR.message_types_by_name['GetDataContractRequest']
_GETDATACONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['GetDataContractResponse']
_CREATEDATACONTRACTREQUEST = DESCRIPTOR.message_types_by_name['CreateDataContractRequest']
_CREATEDATACONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['CreateDataContractResponse']
_UPDATEDATACONTRACTREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataContractRequest']
_UPDATEDATACONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['UpdateDataContractResponse']
_REVIEWDATACONTRACTREQUEST = DESCRIPTOR.message_types_by_name['ReviewDataContractRequest']
_REVIEWDATACONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['ReviewDataContractResponse']
_ACTIVATEDATACONTRACTREQUEST = DESCRIPTOR.message_types_by_name['ActivateDataContractRequest']
_ACTIVATEDATACONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['ActivateDataContractResponse']
_DELETEDATACONTRACTREQUEST = DESCRIPTOR.message_types_by_name['DeleteDataContractRequest']
_DELETEDATACONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['DeleteDataContractResponse']
_ARCHIVEDATACONTRACTREQUEST = DESCRIPTOR.message_types_by_name['ArchiveDataContractRequest']
_ARCHIVEDATACONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['ArchiveDataContractResponse']
_VALIDATEDATACONTRACTSMASKEDFIELDSREQUEST = DESCRIPTOR.message_types_by_name['ValidateDataContractsMaskedFieldsRequest']
_VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE = DESCRIPTOR.message_types_by_name['ValidateDataContractsMaskedFieldsResponse']
_VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR = _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE.nested_types_by_name['Error']
_VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR_FIELDERROR = _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR.nested_types_by_name['FieldError']
_GETDATACONTRACTSCHEMACODEREQUEST = DESCRIPTOR.message_types_by_name['GetDataContractSchemaCodeRequest']
_GETDATACONTRACTSCHEMACODERESPONSE = DESCRIPTOR.message_types_by_name['GetDataContractSchemaCodeResponse']
_GETDATACONTRACTSCHEMADEFINITIONREQUEST = DESCRIPTOR.message_types_by_name['GetDataContractSchemaDefinitionRequest']
_GETDATACONTRACTSCHEMADEFINITIONRESPONSE = DESCRIPTOR.message_types_by_name['GetDataContractSchemaDefinitionResponse']
ListDataContractsRequest = _reflection.GeneratedProtocolMessageType('ListDataContractsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATACONTRACTSREQUEST,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.ListDataContractsRequest)
  })
_sym_db.RegisterMessage(ListDataContractsRequest)

ListDataContractsResponse = _reflection.GeneratedProtocolMessageType('ListDataContractsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATACONTRACTSRESPONSE,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.ListDataContractsResponse)
  })
_sym_db.RegisterMessage(ListDataContractsResponse)

GetDataContractRequest = _reflection.GeneratedProtocolMessageType('GetDataContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATACONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.GetDataContractRequest)
  })
_sym_db.RegisterMessage(GetDataContractRequest)

GetDataContractResponse = _reflection.GeneratedProtocolMessageType('GetDataContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATACONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.GetDataContractResponse)
  })
_sym_db.RegisterMessage(GetDataContractResponse)

CreateDataContractRequest = _reflection.GeneratedProtocolMessageType('CreateDataContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATACONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.CreateDataContractRequest)
  })
_sym_db.RegisterMessage(CreateDataContractRequest)

CreateDataContractResponse = _reflection.GeneratedProtocolMessageType('CreateDataContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATACONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.CreateDataContractResponse)
  })
_sym_db.RegisterMessage(CreateDataContractResponse)

UpdateDataContractRequest = _reflection.GeneratedProtocolMessageType('UpdateDataContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATACONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.UpdateDataContractRequest)
  })
_sym_db.RegisterMessage(UpdateDataContractRequest)

UpdateDataContractResponse = _reflection.GeneratedProtocolMessageType('UpdateDataContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATACONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.UpdateDataContractResponse)
  })
_sym_db.RegisterMessage(UpdateDataContractResponse)

ReviewDataContractRequest = _reflection.GeneratedProtocolMessageType('ReviewDataContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _REVIEWDATACONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.ReviewDataContractRequest)
  })
_sym_db.RegisterMessage(ReviewDataContractRequest)

ReviewDataContractResponse = _reflection.GeneratedProtocolMessageType('ReviewDataContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _REVIEWDATACONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.ReviewDataContractResponse)
  })
_sym_db.RegisterMessage(ReviewDataContractResponse)

ActivateDataContractRequest = _reflection.GeneratedProtocolMessageType('ActivateDataContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATEDATACONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.ActivateDataContractRequest)
  })
_sym_db.RegisterMessage(ActivateDataContractRequest)

ActivateDataContractResponse = _reflection.GeneratedProtocolMessageType('ActivateDataContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATEDATACONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.ActivateDataContractResponse)
  })
_sym_db.RegisterMessage(ActivateDataContractResponse)

DeleteDataContractRequest = _reflection.GeneratedProtocolMessageType('DeleteDataContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATACONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.DeleteDataContractRequest)
  })
_sym_db.RegisterMessage(DeleteDataContractRequest)

DeleteDataContractResponse = _reflection.GeneratedProtocolMessageType('DeleteDataContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATACONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.DeleteDataContractResponse)
  })
_sym_db.RegisterMessage(DeleteDataContractResponse)

ArchiveDataContractRequest = _reflection.GeneratedProtocolMessageType('ArchiveDataContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _ARCHIVEDATACONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.ArchiveDataContractRequest)
  })
_sym_db.RegisterMessage(ArchiveDataContractRequest)

ArchiveDataContractResponse = _reflection.GeneratedProtocolMessageType('ArchiveDataContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _ARCHIVEDATACONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.ArchiveDataContractResponse)
  })
_sym_db.RegisterMessage(ArchiveDataContractResponse)

ValidateDataContractsMaskedFieldsRequest = _reflection.GeneratedProtocolMessageType('ValidateDataContractsMaskedFieldsRequest', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEDATACONTRACTSMASKEDFIELDSREQUEST,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.ValidateDataContractsMaskedFieldsRequest)
  })
_sym_db.RegisterMessage(ValidateDataContractsMaskedFieldsRequest)

ValidateDataContractsMaskedFieldsResponse = _reflection.GeneratedProtocolMessageType('ValidateDataContractsMaskedFieldsResponse', (_message.Message,), {

  'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {

    'FieldError' : _reflection.GeneratedProtocolMessageType('FieldError', (_message.Message,), {
      'DESCRIPTOR' : _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR_FIELDERROR,
      '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
      # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.ValidateDataContractsMaskedFieldsResponse.Error.FieldError)
      })
    ,
    'DESCRIPTOR' : _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR,
    '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
    # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.ValidateDataContractsMaskedFieldsResponse.Error)
    })
  ,
  'DESCRIPTOR' : _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.ValidateDataContractsMaskedFieldsResponse)
  })
_sym_db.RegisterMessage(ValidateDataContractsMaskedFieldsResponse)
_sym_db.RegisterMessage(ValidateDataContractsMaskedFieldsResponse.Error)
_sym_db.RegisterMessage(ValidateDataContractsMaskedFieldsResponse.Error.FieldError)

GetDataContractSchemaCodeRequest = _reflection.GeneratedProtocolMessageType('GetDataContractSchemaCodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATACONTRACTSCHEMACODEREQUEST,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.GetDataContractSchemaCodeRequest)
  })
_sym_db.RegisterMessage(GetDataContractSchemaCodeRequest)

GetDataContractSchemaCodeResponse = _reflection.GeneratedProtocolMessageType('GetDataContractSchemaCodeResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATACONTRACTSCHEMACODERESPONSE,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.GetDataContractSchemaCodeResponse)
  })
_sym_db.RegisterMessage(GetDataContractSchemaCodeResponse)

GetDataContractSchemaDefinitionRequest = _reflection.GeneratedProtocolMessageType('GetDataContractSchemaDefinitionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATACONTRACTSCHEMADEFINITIONREQUEST,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.GetDataContractSchemaDefinitionRequest)
  })
_sym_db.RegisterMessage(GetDataContractSchemaDefinitionRequest)

GetDataContractSchemaDefinitionResponse = _reflection.GeneratedProtocolMessageType('GetDataContractSchemaDefinitionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATACONTRACTSCHEMADEFINITIONRESPONSE,
  '__module__' : 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_contracts.v1.GetDataContractSchemaDefinitionResponse)
  })
_sym_db.RegisterMessage(GetDataContractSchemaDefinitionResponse)

_DATACONTRACTSSERVICE = DESCRIPTOR.services_by_name['DataContractsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$io.strmprivacy.api.data_contracts.v1P\001ZQgithub.com/strmprivacy/api-definitions-go/v2/api/data_contracts/v1;data_contracts'
  _LISTDATACONTRACTSREQUEST.fields_by_name['billing_id']._options = None
  _LISTDATACONTRACTSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _LISTDATACONTRACTSREQUEST.fields_by_name['filter']._options = None
  _LISTDATACONTRACTSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTDATACONTRACTSREQUEST.fields_by_name['handle']._options = None
  _LISTDATACONTRACTSREQUEST.fields_by_name['handle']._serialized_options = b'\340A\001'
  _LISTDATACONTRACTSREQUEST.fields_by_name['name']._options = None
  _LISTDATACONTRACTSREQUEST.fields_by_name['name']._serialized_options = b'\340A\001'
  _LISTDATACONTRACTSREQUEST.fields_by_name['public_private']._options = None
  _LISTDATACONTRACTSREQUEST.fields_by_name['public_private']._serialized_options = b'\340A\001'
  _LISTDATACONTRACTSREQUEST.fields_by_name['labels']._options = None
  _LISTDATACONTRACTSREQUEST.fields_by_name['labels']._serialized_options = b'\340A\001'
  _LISTDATACONTRACTSREQUEST.fields_by_name['domains']._options = None
  _LISTDATACONTRACTSREQUEST.fields_by_name['domains']._serialized_options = b'\340A\001'
  _LISTDATACONTRACTSREQUEST.fields_by_name['industries']._options = None
  _LISTDATACONTRACTSREQUEST.fields_by_name['industries']._serialized_options = b'\340A\001'
  _LISTDATACONTRACTSREQUEST.fields_by_name['project_id']._options = None
  _LISTDATACONTRACTSREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _GETDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _GETDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _GETDATACONTRACTRESPONSE.fields_by_name['checksum']._options = None
  _GETDATACONTRACTRESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _CREATEDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _CREATEDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _CREATEDATACONTRACTRESPONSE.fields_by_name['checksum']._options = None
  _CREATEDATACONTRACTRESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\003'
  _UPDATEDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _UPDATEDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _UPDATEDATACONTRACTREQUEST.fields_by_name['data_contract']._options = None
  _UPDATEDATACONTRACTREQUEST.fields_by_name['data_contract']._serialized_options = b'\340A\002'
  _UPDATEDATACONTRACTREQUEST.fields_by_name['checksum']._options = None
  _UPDATEDATACONTRACTREQUEST.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _UPDATEDATACONTRACTREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEDATACONTRACTREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _UPDATEDATACONTRACTRESPONSE.fields_by_name['checksum']._options = None
  _UPDATEDATACONTRACTRESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\003'
  _REVIEWDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _REVIEWDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _REVIEWDATACONTRACTREQUEST.fields_by_name['id']._options = None
  _REVIEWDATACONTRACTREQUEST.fields_by_name['id']._serialized_options = b'\340A\002'
  _ACTIVATEDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _ACTIVATEDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _ACTIVATEDATACONTRACTREQUEST.fields_by_name['id']._options = None
  _ACTIVATEDATACONTRACTREQUEST.fields_by_name['id']._serialized_options = b'\340A\002'
  _DELETEDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _DELETEDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _DELETEDATACONTRACTREQUEST.fields_by_name['id']._options = None
  _DELETEDATACONTRACTREQUEST.fields_by_name['id']._serialized_options = b'\340A\002'
  _ARCHIVEDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _ARCHIVEDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _ARCHIVEDATACONTRACTREQUEST.fields_by_name['id']._options = None
  _ARCHIVEDATACONTRACTREQUEST.fields_by_name['id']._serialized_options = b'\340A\002'
  _VALIDATEDATACONTRACTSMASKEDFIELDSREQUEST.fields_by_name['billing_id']._options = None
  _VALIDATEDATACONTRACTSMASKEDFIELDSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR.fields_by_name['id']._options = None
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR.fields_by_name['id']._serialized_options = b'\340A\002'
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR.fields_by_name['data_contract_ref']._options = None
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR.fields_by_name['data_contract_ref']._serialized_options = b'\340A\002'
  _GETDATACONTRACTSCHEMACODEREQUEST.fields_by_name['billing_id']._options = None
  _GETDATACONTRACTSCHEMACODEREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _GETDATACONTRACTSCHEMACODEREQUEST.fields_by_name['id']._options = None
  _GETDATACONTRACTSCHEMACODEREQUEST.fields_by_name['id']._serialized_options = b'\340A\002'
  _GETDATACONTRACTSCHEMACODEREQUEST.fields_by_name['language']._options = None
  _GETDATACONTRACTSCHEMACODEREQUEST.fields_by_name['language']._serialized_options = b'\340A\002'
  _LISTDATACONTRACTSREQUEST._serialized_start=211
  _LISTDATACONTRACTSREQUEST._serialized_end=530
  _LISTDATACONTRACTSRESPONSE._serialized_start=532
  _LISTDATACONTRACTSRESPONSE._serialized_end=626
  _GETDATACONTRACTREQUEST._serialized_start=628
  _GETDATACONTRACTREQUEST._serialized_end=747
  _GETDATACONTRACTRESPONSE._serialized_start=749
  _GETDATACONTRACTRESPONSE._serialized_end=863
  _CREATEDATACONTRACTREQUEST._serialized_start=866
  _CREATEDATACONTRACTREQUEST._serialized_end=1003
  _CREATEDATACONTRACTRESPONSE._serialized_start=1005
  _CREATEDATACONTRACTRESPONSE._serialized_end=1122
  _UPDATEDATACONTRACTREQUEST._serialized_start=1125
  _UPDATEDATACONTRACTREQUEST._serialized_end=1324
  _UPDATEDATACONTRACTRESPONSE._serialized_start=1326
  _UPDATEDATACONTRACTRESPONSE._serialized_end=1443
  _REVIEWDATACONTRACTREQUEST._serialized_start=1445
  _REVIEWDATACONTRACTREQUEST._serialized_end=1513
  _REVIEWDATACONTRACTRESPONSE._serialized_start=1515
  _REVIEWDATACONTRACTRESPONSE._serialized_end=1543
  _ACTIVATEDATACONTRACTREQUEST._serialized_start=1545
  _ACTIVATEDATACONTRACTREQUEST._serialized_end=1615
  _ACTIVATEDATACONTRACTRESPONSE._serialized_start=1617
  _ACTIVATEDATACONTRACTRESPONSE._serialized_end=1647
  _DELETEDATACONTRACTREQUEST._serialized_start=1649
  _DELETEDATACONTRACTREQUEST._serialized_end=1717
  _DELETEDATACONTRACTRESPONSE._serialized_start=1719
  _DELETEDATACONTRACTRESPONSE._serialized_end=1747
  _ARCHIVEDATACONTRACTREQUEST._serialized_start=1749
  _ARCHIVEDATACONTRACTREQUEST._serialized_end=1818
  _ARCHIVEDATACONTRACTRESPONSE._serialized_start=1820
  _ARCHIVEDATACONTRACTRESPONSE._serialized_end=1849
  _VALIDATEDATACONTRACTSMASKEDFIELDSREQUEST._serialized_start=1852
  _VALIDATEDATACONTRACTSMASKEDFIELDSREQUEST._serialized_end=1984
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE._serialized_start=1987
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE._serialized_end=2437
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR._serialized_start=2133
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR._serialized_end=2437
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR_FIELDERROR._serialized_start=2365
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR_FIELDERROR._serialized_end=2437
  _GETDATACONTRACTSCHEMACODEREQUEST._serialized_start=2439
  _GETDATACONTRACTSCHEMACODEREQUEST._serialized_end=2537
  _GETDATACONTRACTSCHEMACODERESPONSE._serialized_start=2539
  _GETDATACONTRACTSCHEMACODERESPONSE._serialized_end=2625
  _GETDATACONTRACTSCHEMADEFINITIONREQUEST._serialized_start=2628
  _GETDATACONTRACTSCHEMADEFINITIONREQUEST._serialized_end=2757
  _GETDATACONTRACTSCHEMADEFINITIONRESPONSE._serialized_start=2759
  _GETDATACONTRACTSCHEMADEFINITIONRESPONSE._serialized_end=2820
  _DATACONTRACTSSERVICE._serialized_start=2823
  _DATACONTRACTSSERVICE._serialized_end=4575
# @@protoc_insertion_point(module_scope)
