# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/schemas/v1/schemas_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+strmprivacy/api/schemas/v1/schemas_v1.proto\x12\x1astrmprivacy.api.schemas.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"\xe4\x02\n\x12ListSchemasRequest\x12\x17\n\nbilling_id\x18\x01 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06handle\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x11\n\x04name\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12M\n\x0epublic_private\x18\x05 \x01(\x0e\x32\x30.strmprivacy.api.entities.v1.FilterPublicPrivateB\x03\xe0\x41\x01\x12\x41\n\x0bschema_type\x18\x06 \x01(\x0e\x32\'.strmprivacy.api.entities.v1.SchemaTypeB\x03\xe0\x41\x01\x12\x37\n\x06labels\x18\x07 \x03(\x0b\x32\".strmprivacy.api.entities.v1.LabelB\x03\xe0\x41\x01\x12\x14\n\x07\x64omains\x18\x08 \x03(\tB\x03\xe0\x41\x01\x12\x17\n\nindustries\x18\t \x03(\tB\x03\xe0\x41\x01\"K\n\x13ListSchemasResponse\x12\x34\n\x07schemas\x18\x01 \x03(\x0b\x32#.strmprivacy.api.entities.v1.Schema\"\xa2\x01\n\x10GetSchemaRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x33\n\x03ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRef\x12\x41\n\x0b\x63luster_ref\x18\x03 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRef\"u\n\x11GetSchemaResponse\x12\x33\n\x06schema\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.Schema\x12\x14\n\x0c\x63onfluent_id\x18\x02 \x01(\x05\x12\x15\n\x08\x63hecksum\x18\x03 \x01(\tB\x03\xe0\x41\x02\"v\n\x13\x43reateSchemaRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x33\n\x06schema\x18\x02 \x01(\x0b\x32#.strmprivacy.api.entities.v1.Schema\x12\x12\n\nproject_id\x18\x03 \x01(\t\"b\n\x14\x43reateSchemaResponse\x12\x33\n\x06schema\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.Schema\x12\x15\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x03\"\xcd\x01\n\x13UpdateSchemaRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x38\n\x06schema\x18\x02 \x01(\x0b\x32#.strmprivacy.api.entities.v1.SchemaB\x03\xe0\x41\x02\x12\x15\n\x08\x63hecksum\x18\x03 \x01(\tB\x03\xe0\x41\x02\x12\x34\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x05 \x01(\tB\x03\xe0\x41\x02\"b\n\x14UpdateSchemaResponse\x12\x33\n\x06schema\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.Schema\x12\x15\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x03\"\x89\x01\n\x15\x41\x63tivateSchemaRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12?\n\nschema_ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefB\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"\x18\n\x16\x41\x63tivateSchemaResponse\"\x87\x01\n\x13\x44\x65leteSchemaRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12?\n\nschema_ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefB\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"\x16\n\x14\x44\x65leteSchemaResponse\"\x88\x01\n\x14\x41rchiveSchemaRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12?\n\nschema_ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefB\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"\x17\n\x15\x41rchiveSchemaResponse\"u\n\x14GetSchemaCodeRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x33\n\x03ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRef\x12\x10\n\x08language\x18\x03 \x01(\t\"J\n\x15GetSchemaCodeResponse\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x11\n\tdata_size\x18\x02 \x01(\x03\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"u\n\x1aGetSchemaDefinitionRequest\x12\x14\n\x0c\x63onfluent_id\x18\x01 \x01(\x05\x12\x41\n\x0b\x63luster_ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRef\"1\n\x1bGetSchemaDefinitionResponse\x12\x12\n\ndefinition\x18\x01 \x01(\t2\xb1\x08\n\x0eSchemasService\x12n\n\x0bListSchemas\x12..strmprivacy.api.schemas.v1.ListSchemasRequest\x1a/.strmprivacy.api.schemas.v1.ListSchemasResponse\x12h\n\tGetSchema\x12,.strmprivacy.api.schemas.v1.GetSchemaRequest\x1a-.strmprivacy.api.schemas.v1.GetSchemaResponse\x12q\n\x0c\x43reateSchema\x12/.strmprivacy.api.schemas.v1.CreateSchemaRequest\x1a\x30.strmprivacy.api.schemas.v1.CreateSchemaResponse\x12q\n\x0cUpdateSchema\x12/.strmprivacy.api.schemas.v1.UpdateSchemaRequest\x1a\x30.strmprivacy.api.schemas.v1.UpdateSchemaResponse\x12t\n\rGetSchemaCode\x12\x30.strmprivacy.api.schemas.v1.GetSchemaCodeRequest\x1a\x31.strmprivacy.api.schemas.v1.GetSchemaCodeResponse\x12w\n\x0e\x41\x63tivateSchema\x12\x31.strmprivacy.api.schemas.v1.ActivateSchemaRequest\x1a\x32.strmprivacy.api.schemas.v1.ActivateSchemaResponse\x12q\n\x0c\x44\x65leteSchema\x12/.strmprivacy.api.schemas.v1.DeleteSchemaRequest\x1a\x30.strmprivacy.api.schemas.v1.DeleteSchemaResponse\x12t\n\rArchiveSchema\x12\x30.strmprivacy.api.schemas.v1.ArchiveSchemaRequest\x1a\x31.strmprivacy.api.schemas.v1.ArchiveSchemaResponse\x12\x86\x01\n\x13GetSchemaDefinition\x12\x36.strmprivacy.api.schemas.v1.GetSchemaDefinitionRequest\x1a\x37.strmprivacy.api.schemas.v1.GetSchemaDefinitionResponseBf\n\x1dio.strmprivacy.api.schemas.v1P\x01ZCgithub.com/strmprivacy/api-definitions-go/v2/api/schemas/v1;schemasb\x06proto3')



_LISTSCHEMASREQUEST = DESCRIPTOR.message_types_by_name['ListSchemasRequest']
_LISTSCHEMASRESPONSE = DESCRIPTOR.message_types_by_name['ListSchemasResponse']
_GETSCHEMAREQUEST = DESCRIPTOR.message_types_by_name['GetSchemaRequest']
_GETSCHEMARESPONSE = DESCRIPTOR.message_types_by_name['GetSchemaResponse']
_CREATESCHEMAREQUEST = DESCRIPTOR.message_types_by_name['CreateSchemaRequest']
_CREATESCHEMARESPONSE = DESCRIPTOR.message_types_by_name['CreateSchemaResponse']
_UPDATESCHEMAREQUEST = DESCRIPTOR.message_types_by_name['UpdateSchemaRequest']
_UPDATESCHEMARESPONSE = DESCRIPTOR.message_types_by_name['UpdateSchemaResponse']
_ACTIVATESCHEMAREQUEST = DESCRIPTOR.message_types_by_name['ActivateSchemaRequest']
_ACTIVATESCHEMARESPONSE = DESCRIPTOR.message_types_by_name['ActivateSchemaResponse']
_DELETESCHEMAREQUEST = DESCRIPTOR.message_types_by_name['DeleteSchemaRequest']
_DELETESCHEMARESPONSE = DESCRIPTOR.message_types_by_name['DeleteSchemaResponse']
_ARCHIVESCHEMAREQUEST = DESCRIPTOR.message_types_by_name['ArchiveSchemaRequest']
_ARCHIVESCHEMARESPONSE = DESCRIPTOR.message_types_by_name['ArchiveSchemaResponse']
_GETSCHEMACODEREQUEST = DESCRIPTOR.message_types_by_name['GetSchemaCodeRequest']
_GETSCHEMACODERESPONSE = DESCRIPTOR.message_types_by_name['GetSchemaCodeResponse']
_GETSCHEMADEFINITIONREQUEST = DESCRIPTOR.message_types_by_name['GetSchemaDefinitionRequest']
_GETSCHEMADEFINITIONRESPONSE = DESCRIPTOR.message_types_by_name['GetSchemaDefinitionResponse']
ListSchemasRequest = _reflection.GeneratedProtocolMessageType('ListSchemasRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSCHEMASREQUEST,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.ListSchemasRequest)
  })
_sym_db.RegisterMessage(ListSchemasRequest)

ListSchemasResponse = _reflection.GeneratedProtocolMessageType('ListSchemasResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSCHEMASRESPONSE,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.ListSchemasResponse)
  })
_sym_db.RegisterMessage(ListSchemasResponse)

GetSchemaRequest = _reflection.GeneratedProtocolMessageType('GetSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSCHEMAREQUEST,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.GetSchemaRequest)
  })
_sym_db.RegisterMessage(GetSchemaRequest)

GetSchemaResponse = _reflection.GeneratedProtocolMessageType('GetSchemaResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSCHEMARESPONSE,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.GetSchemaResponse)
  })
_sym_db.RegisterMessage(GetSchemaResponse)

CreateSchemaRequest = _reflection.GeneratedProtocolMessageType('CreateSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESCHEMAREQUEST,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.CreateSchemaRequest)
  })
_sym_db.RegisterMessage(CreateSchemaRequest)

CreateSchemaResponse = _reflection.GeneratedProtocolMessageType('CreateSchemaResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESCHEMARESPONSE,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.CreateSchemaResponse)
  })
_sym_db.RegisterMessage(CreateSchemaResponse)

UpdateSchemaRequest = _reflection.GeneratedProtocolMessageType('UpdateSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESCHEMAREQUEST,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.UpdateSchemaRequest)
  })
_sym_db.RegisterMessage(UpdateSchemaRequest)

UpdateSchemaResponse = _reflection.GeneratedProtocolMessageType('UpdateSchemaResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESCHEMARESPONSE,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.UpdateSchemaResponse)
  })
_sym_db.RegisterMessage(UpdateSchemaResponse)

ActivateSchemaRequest = _reflection.GeneratedProtocolMessageType('ActivateSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATESCHEMAREQUEST,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.ActivateSchemaRequest)
  })
_sym_db.RegisterMessage(ActivateSchemaRequest)

ActivateSchemaResponse = _reflection.GeneratedProtocolMessageType('ActivateSchemaResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATESCHEMARESPONSE,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.ActivateSchemaResponse)
  })
_sym_db.RegisterMessage(ActivateSchemaResponse)

DeleteSchemaRequest = _reflection.GeneratedProtocolMessageType('DeleteSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESCHEMAREQUEST,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.DeleteSchemaRequest)
  })
_sym_db.RegisterMessage(DeleteSchemaRequest)

DeleteSchemaResponse = _reflection.GeneratedProtocolMessageType('DeleteSchemaResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETESCHEMARESPONSE,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.DeleteSchemaResponse)
  })
_sym_db.RegisterMessage(DeleteSchemaResponse)

ArchiveSchemaRequest = _reflection.GeneratedProtocolMessageType('ArchiveSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _ARCHIVESCHEMAREQUEST,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.ArchiveSchemaRequest)
  })
_sym_db.RegisterMessage(ArchiveSchemaRequest)

ArchiveSchemaResponse = _reflection.GeneratedProtocolMessageType('ArchiveSchemaResponse', (_message.Message,), {
  'DESCRIPTOR' : _ARCHIVESCHEMARESPONSE,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.ArchiveSchemaResponse)
  })
_sym_db.RegisterMessage(ArchiveSchemaResponse)

GetSchemaCodeRequest = _reflection.GeneratedProtocolMessageType('GetSchemaCodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSCHEMACODEREQUEST,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.GetSchemaCodeRequest)
  })
_sym_db.RegisterMessage(GetSchemaCodeRequest)

GetSchemaCodeResponse = _reflection.GeneratedProtocolMessageType('GetSchemaCodeResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSCHEMACODERESPONSE,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.GetSchemaCodeResponse)
  })
_sym_db.RegisterMessage(GetSchemaCodeResponse)

GetSchemaDefinitionRequest = _reflection.GeneratedProtocolMessageType('GetSchemaDefinitionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSCHEMADEFINITIONREQUEST,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.GetSchemaDefinitionRequest)
  })
_sym_db.RegisterMessage(GetSchemaDefinitionRequest)

GetSchemaDefinitionResponse = _reflection.GeneratedProtocolMessageType('GetSchemaDefinitionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSCHEMADEFINITIONRESPONSE,
  '__module__' : 'strmprivacy.api.schemas.v1.schemas_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.schemas.v1.GetSchemaDefinitionResponse)
  })
_sym_db.RegisterMessage(GetSchemaDefinitionResponse)

_SCHEMASSERVICE = DESCRIPTOR.services_by_name['SchemasService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035io.strmprivacy.api.schemas.v1P\001ZCgithub.com/strmprivacy/api-definitions-go/v2/api/schemas/v1;schemas'
  _LISTSCHEMASREQUEST.fields_by_name['billing_id']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['billing_id']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['filter']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['handle']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['handle']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['name']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['name']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['public_private']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['public_private']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['schema_type']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['schema_type']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['labels']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['labels']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['domains']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['domains']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['industries']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['industries']._serialized_options = b'\340A\001'
  _GETSCHEMAREQUEST.fields_by_name['billing_id']._options = None
  _GETSCHEMAREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _GETSCHEMARESPONSE.fields_by_name['checksum']._options = None
  _GETSCHEMARESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _CREATESCHEMAREQUEST.fields_by_name['billing_id']._options = None
  _CREATESCHEMAREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _CREATESCHEMARESPONSE.fields_by_name['checksum']._options = None
  _CREATESCHEMARESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\003'
  _UPDATESCHEMAREQUEST.fields_by_name['billing_id']._options = None
  _UPDATESCHEMAREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _UPDATESCHEMAREQUEST.fields_by_name['schema']._options = None
  _UPDATESCHEMAREQUEST.fields_by_name['schema']._serialized_options = b'\340A\002'
  _UPDATESCHEMAREQUEST.fields_by_name['checksum']._options = None
  _UPDATESCHEMAREQUEST.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _UPDATESCHEMAREQUEST.fields_by_name['update_mask']._options = None
  _UPDATESCHEMAREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _UPDATESCHEMAREQUEST.fields_by_name['project_id']._options = None
  _UPDATESCHEMAREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _UPDATESCHEMARESPONSE.fields_by_name['checksum']._options = None
  _UPDATESCHEMARESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\003'
  _ACTIVATESCHEMAREQUEST.fields_by_name['billing_id']._options = None
  _ACTIVATESCHEMAREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _ACTIVATESCHEMAREQUEST.fields_by_name['schema_ref']._options = None
  _ACTIVATESCHEMAREQUEST.fields_by_name['schema_ref']._serialized_options = b'\340A\002'
  _ACTIVATESCHEMAREQUEST.fields_by_name['project_id']._options = None
  _ACTIVATESCHEMAREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _DELETESCHEMAREQUEST.fields_by_name['billing_id']._options = None
  _DELETESCHEMAREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _DELETESCHEMAREQUEST.fields_by_name['schema_ref']._options = None
  _DELETESCHEMAREQUEST.fields_by_name['schema_ref']._serialized_options = b'\340A\002'
  _DELETESCHEMAREQUEST.fields_by_name['project_id']._options = None
  _DELETESCHEMAREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _ARCHIVESCHEMAREQUEST.fields_by_name['billing_id']._options = None
  _ARCHIVESCHEMAREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _ARCHIVESCHEMAREQUEST.fields_by_name['schema_ref']._options = None
  _ARCHIVESCHEMAREQUEST.fields_by_name['schema_ref']._serialized_options = b'\340A\002'
  _ARCHIVESCHEMAREQUEST.fields_by_name['project_id']._options = None
  _ARCHIVESCHEMAREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _GETSCHEMACODEREQUEST.fields_by_name['billing_id']._options = None
  _GETSCHEMACODEREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _LISTSCHEMASREQUEST._serialized_start=190
  _LISTSCHEMASREQUEST._serialized_end=546
  _LISTSCHEMASRESPONSE._serialized_start=548
  _LISTSCHEMASRESPONSE._serialized_end=623
  _GETSCHEMAREQUEST._serialized_start=626
  _GETSCHEMAREQUEST._serialized_end=788
  _GETSCHEMARESPONSE._serialized_start=790
  _GETSCHEMARESPONSE._serialized_end=907
  _CREATESCHEMAREQUEST._serialized_start=909
  _CREATESCHEMAREQUEST._serialized_end=1027
  _CREATESCHEMARESPONSE._serialized_start=1029
  _CREATESCHEMARESPONSE._serialized_end=1127
  _UPDATESCHEMAREQUEST._serialized_start=1130
  _UPDATESCHEMAREQUEST._serialized_end=1335
  _UPDATESCHEMARESPONSE._serialized_start=1337
  _UPDATESCHEMARESPONSE._serialized_end=1435
  _ACTIVATESCHEMAREQUEST._serialized_start=1438
  _ACTIVATESCHEMAREQUEST._serialized_end=1575
  _ACTIVATESCHEMARESPONSE._serialized_start=1577
  _ACTIVATESCHEMARESPONSE._serialized_end=1601
  _DELETESCHEMAREQUEST._serialized_start=1604
  _DELETESCHEMAREQUEST._serialized_end=1739
  _DELETESCHEMARESPONSE._serialized_start=1741
  _DELETESCHEMARESPONSE._serialized_end=1763
  _ARCHIVESCHEMAREQUEST._serialized_start=1766
  _ARCHIVESCHEMAREQUEST._serialized_end=1902
  _ARCHIVESCHEMARESPONSE._serialized_start=1904
  _ARCHIVESCHEMARESPONSE._serialized_end=1927
  _GETSCHEMACODEREQUEST._serialized_start=1929
  _GETSCHEMACODEREQUEST._serialized_end=2046
  _GETSCHEMACODERESPONSE._serialized_start=2048
  _GETSCHEMACODERESPONSE._serialized_end=2122
  _GETSCHEMADEFINITIONREQUEST._serialized_start=2124
  _GETSCHEMADEFINITIONREQUEST._serialized_end=2241
  _GETSCHEMADEFINITIONRESPONSE._serialized_start=2243
  _GETSCHEMADEFINITIONRESPONSE._serialized_end=2292
  _SCHEMASSERVICE._serialized_start=2295
  _SCHEMASSERVICE._serialized_end=3368
# @@protoc_insertion_point(module_scope)
