# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/installations/v1/entities_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2strmprivacy/api/installations/v1/entities_v1.proto\x12 strmprivacy.api.installations.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xec\x01\n\x0cInstallation\x12\x0f\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12R\n\x11installation_type\x18\x02 \x01(\x0e\x32\x32.strmprivacy.api.installations.v1.InstallationTypeB\x03\xe0\x41\x02\x12\x1a\n\x12\x62illing_account_id\x18\x03 \x01(\t\x12[\n\x18installation_credentials\x18\x04 \x01(\x0b\x32\x39.strmprivacy.api.installations.v1.InstallationCredentials\"m\n\x17InstallationCredentials\x12\x16\n\tclient_id\x18\x01 \x01(\tB\x03\xe0\x41\x03\x12\x1a\n\rclient_secret\x18\x02 \x01(\tB\x03\xe0\x41\x03\x12\x1e\n\x11image_pull_secret\x18\x03 \x01(\tB\x03\xe0\x41\x03\"\xbc\x01\n\x12InstalledComponent\x12U\n\x0e\x63omponent_type\x18\x01 \x01(\x0e\x32\x38.strmprivacy.api.installations.v1.InstalledComponentTypeB\x03\xe0\x41\x02\x12O\n\tinstances\x18\x02 \x03(\x0b\x32<.strmprivacy.api.installations.v1.InstalledComponentInstance\"x\n\x1aInstalledComponentInstance\x12\x0f\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12I\n\x06states\x18\x02 \x03(\x0b\x32\x39.strmprivacy.api.installations.v1.InstalledComponentState\"\xd5\x01\n\x1fInstalledComponentsCurrentState\x12U\n\x0e\x63omponent_type\x18\x01 \x01(\x0e\x32\x38.strmprivacy.api.installations.v1.InstalledComponentTypeB\x03\xe0\x41\x02\x12[\n\tinstances\x18\x02 \x03(\x0b\x32H.strmprivacy.api.installations.v1.InstalledComponentInstanceCurrentState\"\x83\x01\n&InstalledComponentInstanceCurrentState\x12\x0f\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12H\n\x05state\x18\x02 \x01(\x0b\x32\x39.strmprivacy.api.installations.v1.InstalledComponentState\"\xbc\x01\n\x17InstalledComponentState\x12\x33\n\nstate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03\x12V\n\nstate_type\x18\x02 \x01(\x0e\x32=.strmprivacy.api.installations.v1.InstalledComponentStateTypeB\x03\xe0\x41\x02\x12\x14\n\x07message\x18\x03 \x01(\tB\x03\xe0\x41\x01*e\n\x10InstallationType\x12!\n\x1dINSTALLATION_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04SAAS\x10\x01\x12\x0f\n\x0bSELF_HOSTED\x10\x02\x12\x13\n\x0f\x41WS_MARKETPLACE\x10\x03*\xfb\x01\n\x16InstalledComponentType\x12(\n$INSTALLED_COMPONENT_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x42\x41TCH_JOBS_AGENT\x10\x01\x12\x19\n\x15\x42\x41TCH_EXPORTERS_AGENT\x10\x02\x12\x19\n\x15KAFKA_EXPORTERS_AGENT\x10\x03\x12\x11\n\rSTREAMS_AGENT\x10\x04\x12\x11\n\rEVENT_GATEWAY\x10\x05\x12\x0e\n\nWEB_SOCKET\x10\x06\x12\x19\n\x15\x44\x41TA_CONNECTORS_AGENT\x10\x07\x12\x1a\n\x16\x43ONFLUENT_SCHEMA_PROXY\x10\x08*\x89\x01\n\x1bInstalledComponentStateType\x12.\n*INSTALLED_COMPONENT_STATE_TYPE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bPROVISIONED\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x11\n\rSHUTTING_DOWN\x10\x04\x42x\n#io.strmprivacy.api.installations.v1P\x01ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installationsb\x06proto3')

_INSTALLATIONTYPE = DESCRIPTOR.enum_types_by_name['InstallationType']
InstallationType = enum_type_wrapper.EnumTypeWrapper(_INSTALLATIONTYPE)
_INSTALLEDCOMPONENTTYPE = DESCRIPTOR.enum_types_by_name['InstalledComponentType']
InstalledComponentType = enum_type_wrapper.EnumTypeWrapper(_INSTALLEDCOMPONENTTYPE)
_INSTALLEDCOMPONENTSTATETYPE = DESCRIPTOR.enum_types_by_name['InstalledComponentStateType']
InstalledComponentStateType = enum_type_wrapper.EnumTypeWrapper(_INSTALLEDCOMPONENTSTATETYPE)
INSTALLATION_TYPE_UNSPECIFIED = 0
SAAS = 1
SELF_HOSTED = 2
AWS_MARKETPLACE = 3
INSTALLED_COMPONENT_TYPE_UNSPECIFIED = 0
BATCH_JOBS_AGENT = 1
BATCH_EXPORTERS_AGENT = 2
KAFKA_EXPORTERS_AGENT = 3
STREAMS_AGENT = 4
EVENT_GATEWAY = 5
WEB_SOCKET = 6
DATA_CONNECTORS_AGENT = 7
CONFLUENT_SCHEMA_PROXY = 8
INSTALLED_COMPONENT_STATE_TYPE_UNSPECIFIED = 0
PROVISIONED = 1
RUNNING = 2
ERROR = 3
SHUTTING_DOWN = 4


_INSTALLATION = DESCRIPTOR.message_types_by_name['Installation']
_INSTALLATIONCREDENTIALS = DESCRIPTOR.message_types_by_name['InstallationCredentials']
_INSTALLEDCOMPONENT = DESCRIPTOR.message_types_by_name['InstalledComponent']
_INSTALLEDCOMPONENTINSTANCE = DESCRIPTOR.message_types_by_name['InstalledComponentInstance']
_INSTALLEDCOMPONENTSCURRENTSTATE = DESCRIPTOR.message_types_by_name['InstalledComponentsCurrentState']
_INSTALLEDCOMPONENTINSTANCECURRENTSTATE = DESCRIPTOR.message_types_by_name['InstalledComponentInstanceCurrentState']
_INSTALLEDCOMPONENTSTATE = DESCRIPTOR.message_types_by_name['InstalledComponentState']
Installation = _reflection.GeneratedProtocolMessageType('Installation', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLATION,
  '__module__' : 'strmprivacy.api.installations.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.Installation)
  })
_sym_db.RegisterMessage(Installation)

InstallationCredentials = _reflection.GeneratedProtocolMessageType('InstallationCredentials', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLATIONCREDENTIALS,
  '__module__' : 'strmprivacy.api.installations.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.InstallationCredentials)
  })
_sym_db.RegisterMessage(InstallationCredentials)

InstalledComponent = _reflection.GeneratedProtocolMessageType('InstalledComponent', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLEDCOMPONENT,
  '__module__' : 'strmprivacy.api.installations.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.InstalledComponent)
  })
_sym_db.RegisterMessage(InstalledComponent)

InstalledComponentInstance = _reflection.GeneratedProtocolMessageType('InstalledComponentInstance', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLEDCOMPONENTINSTANCE,
  '__module__' : 'strmprivacy.api.installations.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.InstalledComponentInstance)
  })
_sym_db.RegisterMessage(InstalledComponentInstance)

InstalledComponentsCurrentState = _reflection.GeneratedProtocolMessageType('InstalledComponentsCurrentState', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLEDCOMPONENTSCURRENTSTATE,
  '__module__' : 'strmprivacy.api.installations.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.InstalledComponentsCurrentState)
  })
_sym_db.RegisterMessage(InstalledComponentsCurrentState)

InstalledComponentInstanceCurrentState = _reflection.GeneratedProtocolMessageType('InstalledComponentInstanceCurrentState', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLEDCOMPONENTINSTANCECURRENTSTATE,
  '__module__' : 'strmprivacy.api.installations.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.InstalledComponentInstanceCurrentState)
  })
_sym_db.RegisterMessage(InstalledComponentInstanceCurrentState)

InstalledComponentState = _reflection.GeneratedProtocolMessageType('InstalledComponentState', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLEDCOMPONENTSTATE,
  '__module__' : 'strmprivacy.api.installations.v1.entities_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.InstalledComponentState)
  })
_sym_db.RegisterMessage(InstalledComponentState)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.installations.v1P\001ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installations'
  _INSTALLATION.fields_by_name['id']._options = None
  _INSTALLATION.fields_by_name['id']._serialized_options = b'\340A\002'
  _INSTALLATION.fields_by_name['installation_type']._options = None
  _INSTALLATION.fields_by_name['installation_type']._serialized_options = b'\340A\002'
  _INSTALLATIONCREDENTIALS.fields_by_name['client_id']._options = None
  _INSTALLATIONCREDENTIALS.fields_by_name['client_id']._serialized_options = b'\340A\003'
  _INSTALLATIONCREDENTIALS.fields_by_name['client_secret']._options = None
  _INSTALLATIONCREDENTIALS.fields_by_name['client_secret']._serialized_options = b'\340A\003'
  _INSTALLATIONCREDENTIALS.fields_by_name['image_pull_secret']._options = None
  _INSTALLATIONCREDENTIALS.fields_by_name['image_pull_secret']._serialized_options = b'\340A\003'
  _INSTALLEDCOMPONENT.fields_by_name['component_type']._options = None
  _INSTALLEDCOMPONENT.fields_by_name['component_type']._serialized_options = b'\340A\002'
  _INSTALLEDCOMPONENTINSTANCE.fields_by_name['id']._options = None
  _INSTALLEDCOMPONENTINSTANCE.fields_by_name['id']._serialized_options = b'\340A\002'
  _INSTALLEDCOMPONENTSCURRENTSTATE.fields_by_name['component_type']._options = None
  _INSTALLEDCOMPONENTSCURRENTSTATE.fields_by_name['component_type']._serialized_options = b'\340A\002'
  _INSTALLEDCOMPONENTINSTANCECURRENTSTATE.fields_by_name['id']._options = None
  _INSTALLEDCOMPONENTINSTANCECURRENTSTATE.fields_by_name['id']._serialized_options = b'\340A\002'
  _INSTALLEDCOMPONENTSTATE.fields_by_name['state_time']._options = None
  _INSTALLEDCOMPONENTSTATE.fields_by_name['state_time']._serialized_options = b'\340A\003'
  _INSTALLEDCOMPONENTSTATE.fields_by_name['state_type']._options = None
  _INSTALLEDCOMPONENTSTATE.fields_by_name['state_type']._serialized_options = b'\340A\002'
  _INSTALLEDCOMPONENTSTATE.fields_by_name['message']._options = None
  _INSTALLEDCOMPONENTSTATE.fields_by_name['message']._serialized_options = b'\340A\001'
  _INSTALLATIONTYPE._serialized_start=1358
  _INSTALLATIONTYPE._serialized_end=1459
  _INSTALLEDCOMPONENTTYPE._serialized_start=1462
  _INSTALLEDCOMPONENTTYPE._serialized_end=1713
  _INSTALLEDCOMPONENTSTATETYPE._serialized_start=1716
  _INSTALLEDCOMPONENTSTATETYPE._serialized_end=1853
  _INSTALLATION._serialized_start=155
  _INSTALLATION._serialized_end=391
  _INSTALLATIONCREDENTIALS._serialized_start=393
  _INSTALLATIONCREDENTIALS._serialized_end=502
  _INSTALLEDCOMPONENT._serialized_start=505
  _INSTALLEDCOMPONENT._serialized_end=693
  _INSTALLEDCOMPONENTINSTANCE._serialized_start=695
  _INSTALLEDCOMPONENTINSTANCE._serialized_end=815
  _INSTALLEDCOMPONENTSCURRENTSTATE._serialized_start=818
  _INSTALLEDCOMPONENTSCURRENTSTATE._serialized_end=1031
  _INSTALLEDCOMPONENTINSTANCECURRENTSTATE._serialized_start=1034
  _INSTALLEDCOMPONENTINSTANCECURRENTSTATE._serialized_end=1165
  _INSTALLEDCOMPONENTSTATE._serialized_start=1168
  _INSTALLEDCOMPONENTSTATE._serialized_end=1356
# @@protoc_insertion_point(module_scope)
