# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/usage/v1/usage_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'strmprivacy/api/usage/v1/usage_v1.proto\x12\x18strmprivacy.api.usage.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"\xdc\x01\n\x1aGetStreamEventUsageRequest\x12\x33\n\x03ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRef\x12.\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x08interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x94\x01\n\x1bGetStreamEventUsageResponse\x12\x33\n\x03ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRef\x12@\n\x07windows\x18\x02 \x03(\x0b\x32/.strmprivacy.api.entities.v1.WindowedEventCount\"\xa1\x01\n\x16StoreUsageEventRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x0e\n\x06stream\x18\x02 \x01(\t\x12\x13\n\x0b\x65vent_count\x18\x03 \x01(\x05\x12\x36\n\x12\x65vent_arrival_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nproject_id\x18\x05 \x01(\t\"\x19\n\x17StoreUsageEventResponse2\x8b\x02\n\x0cUsageService\x12\x82\x01\n\x13GetStreamEventUsage\x12\x34.strmprivacy.api.usage.v1.GetStreamEventUsageRequest\x1a\x35.strmprivacy.api.usage.v1.GetStreamEventUsageResponse\x12v\n\x0fStoreUsageEvent\x12\x30.strmprivacy.api.usage.v1.StoreUsageEventRequest\x1a\x31.strmprivacy.api.usage.v1.StoreUsageEventResponseB`\n\x1bio.strmprivacy.api.usage.v1P\x01Z?github.com/strmprivacy/api-definitions-go/v2/api/usage/v1;usageb\x06proto3')



_GETSTREAMEVENTUSAGEREQUEST = DESCRIPTOR.message_types_by_name['GetStreamEventUsageRequest']
_GETSTREAMEVENTUSAGERESPONSE = DESCRIPTOR.message_types_by_name['GetStreamEventUsageResponse']
_STOREUSAGEEVENTREQUEST = DESCRIPTOR.message_types_by_name['StoreUsageEventRequest']
_STOREUSAGEEVENTRESPONSE = DESCRIPTOR.message_types_by_name['StoreUsageEventResponse']
GetStreamEventUsageRequest = _reflection.GeneratedProtocolMessageType('GetStreamEventUsageRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTREAMEVENTUSAGEREQUEST,
  '__module__' : 'strmprivacy.api.usage.v1.usage_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.usage.v1.GetStreamEventUsageRequest)
  })
_sym_db.RegisterMessage(GetStreamEventUsageRequest)

GetStreamEventUsageResponse = _reflection.GeneratedProtocolMessageType('GetStreamEventUsageResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTREAMEVENTUSAGERESPONSE,
  '__module__' : 'strmprivacy.api.usage.v1.usage_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.usage.v1.GetStreamEventUsageResponse)
  })
_sym_db.RegisterMessage(GetStreamEventUsageResponse)

StoreUsageEventRequest = _reflection.GeneratedProtocolMessageType('StoreUsageEventRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOREUSAGEEVENTREQUEST,
  '__module__' : 'strmprivacy.api.usage.v1.usage_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.usage.v1.StoreUsageEventRequest)
  })
_sym_db.RegisterMessage(StoreUsageEventRequest)

StoreUsageEventResponse = _reflection.GeneratedProtocolMessageType('StoreUsageEventResponse', (_message.Message,), {
  'DESCRIPTOR' : _STOREUSAGEEVENTRESPONSE,
  '__module__' : 'strmprivacy.api.usage.v1.usage_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.usage.v1.StoreUsageEventResponse)
  })
_sym_db.RegisterMessage(StoreUsageEventResponse)

_USAGESERVICE = DESCRIPTOR.services_by_name['UsageService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033io.strmprivacy.api.usage.v1P\001Z?github.com/strmprivacy/api-definitions-go/v2/api/usage/v1;usage'
  _STOREUSAGEEVENTREQUEST.fields_by_name['billing_id']._options = None
  _STOREUSAGEEVENTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _GETSTREAMEVENTUSAGEREQUEST._serialized_start=182
  _GETSTREAMEVENTUSAGEREQUEST._serialized_end=402
  _GETSTREAMEVENTUSAGERESPONSE._serialized_start=405
  _GETSTREAMEVENTUSAGERESPONSE._serialized_end=553
  _STOREUSAGEEVENTREQUEST._serialized_start=556
  _STOREUSAGEEVENTREQUEST._serialized_end=717
  _STOREUSAGEEVENTRESPONSE._serialized_start=719
  _STOREUSAGEEVENTRESPONSE._serialized_end=744
  _USAGESERVICE._serialized_start=747
  _USAGESERVICE._serialized_end=1014
# @@protoc_insertion_point(module_scope)
