# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/credentials/v1/credentials_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3strmprivacy/api/credentials/v1/credentials_v1.proto\x12\x1estrmprivacy.api.credentials.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"Y\n\x16ListCredentialsRequest\x12?\n\nstream_ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefB\x03\xe0\x41\x02\"X\n\x17ListCredentialsResponse\x12=\n\x0b\x63redentials\x18\x01 \x03(\x0b\x32(.strmprivacy.api.entities.v1.Credentials\",\n\x17\x44\x65leteCredentialRequest\x12\x11\n\tclient_id\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteCredentialResponse\")\n\x14GetCredentialRequest\x12\x11\n\tclient_id\x18\x01 \x01(\t\"U\n\x15GetCredentialResponse\x12<\n\ncredential\x18\x01 \x01(\x0b\x32(.strmprivacy.api.entities.v1.Credentials\"U\n\x17\x43reateCredentialRequest\x12:\n\nstream_ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRef\"Y\n\x18\x43reateCredentialResponse\x12=\n\x0b\x63redentials\x18\x01 \x01(\x0b\x32(.strmprivacy.api.entities.v1.Credentials2\xa7\x04\n\x12\x43redentialsService\x12\x82\x01\n\x0fListCredentials\x12\x36.strmprivacy.api.credentials.v1.ListCredentialsRequest\x1a\x37.strmprivacy.api.credentials.v1.ListCredentialsResponse\x12|\n\rGetCredential\x12\x34.strmprivacy.api.credentials.v1.GetCredentialRequest\x1a\x35.strmprivacy.api.credentials.v1.GetCredentialResponse\x12\x85\x01\n\x10\x43reateCredential\x12\x37.strmprivacy.api.credentials.v1.CreateCredentialRequest\x1a\x38.strmprivacy.api.credentials.v1.CreateCredentialResponse\x12\x85\x01\n\x10\x44\x65leteCredential\x12\x37.strmprivacy.api.credentials.v1.DeleteCredentialRequest\x1a\x38.strmprivacy.api.credentials.v1.DeleteCredentialResponseBr\n!io.strmprivacy.api.credentials.v1P\x01ZKgithub.com/strmprivacy/api-definitions-go/v2/api/credentials/v1;credentialsb\x06proto3')



_LISTCREDENTIALSREQUEST = DESCRIPTOR.message_types_by_name['ListCredentialsRequest']
_LISTCREDENTIALSRESPONSE = DESCRIPTOR.message_types_by_name['ListCredentialsResponse']
_DELETECREDENTIALREQUEST = DESCRIPTOR.message_types_by_name['DeleteCredentialRequest']
_DELETECREDENTIALRESPONSE = DESCRIPTOR.message_types_by_name['DeleteCredentialResponse']
_GETCREDENTIALREQUEST = DESCRIPTOR.message_types_by_name['GetCredentialRequest']
_GETCREDENTIALRESPONSE = DESCRIPTOR.message_types_by_name['GetCredentialResponse']
_CREATECREDENTIALREQUEST = DESCRIPTOR.message_types_by_name['CreateCredentialRequest']
_CREATECREDENTIALRESPONSE = DESCRIPTOR.message_types_by_name['CreateCredentialResponse']
ListCredentialsRequest = _reflection.GeneratedProtocolMessageType('ListCredentialsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCREDENTIALSREQUEST,
  '__module__' : 'strmprivacy.api.credentials.v1.credentials_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.credentials.v1.ListCredentialsRequest)
  })
_sym_db.RegisterMessage(ListCredentialsRequest)

ListCredentialsResponse = _reflection.GeneratedProtocolMessageType('ListCredentialsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCREDENTIALSRESPONSE,
  '__module__' : 'strmprivacy.api.credentials.v1.credentials_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.credentials.v1.ListCredentialsResponse)
  })
_sym_db.RegisterMessage(ListCredentialsResponse)

DeleteCredentialRequest = _reflection.GeneratedProtocolMessageType('DeleteCredentialRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECREDENTIALREQUEST,
  '__module__' : 'strmprivacy.api.credentials.v1.credentials_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.credentials.v1.DeleteCredentialRequest)
  })
_sym_db.RegisterMessage(DeleteCredentialRequest)

DeleteCredentialResponse = _reflection.GeneratedProtocolMessageType('DeleteCredentialResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETECREDENTIALRESPONSE,
  '__module__' : 'strmprivacy.api.credentials.v1.credentials_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.credentials.v1.DeleteCredentialResponse)
  })
_sym_db.RegisterMessage(DeleteCredentialResponse)

GetCredentialRequest = _reflection.GeneratedProtocolMessageType('GetCredentialRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCREDENTIALREQUEST,
  '__module__' : 'strmprivacy.api.credentials.v1.credentials_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.credentials.v1.GetCredentialRequest)
  })
_sym_db.RegisterMessage(GetCredentialRequest)

GetCredentialResponse = _reflection.GeneratedProtocolMessageType('GetCredentialResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCREDENTIALRESPONSE,
  '__module__' : 'strmprivacy.api.credentials.v1.credentials_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.credentials.v1.GetCredentialResponse)
  })
_sym_db.RegisterMessage(GetCredentialResponse)

CreateCredentialRequest = _reflection.GeneratedProtocolMessageType('CreateCredentialRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECREDENTIALREQUEST,
  '__module__' : 'strmprivacy.api.credentials.v1.credentials_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.credentials.v1.CreateCredentialRequest)
  })
_sym_db.RegisterMessage(CreateCredentialRequest)

CreateCredentialResponse = _reflection.GeneratedProtocolMessageType('CreateCredentialResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECREDENTIALRESPONSE,
  '__module__' : 'strmprivacy.api.credentials.v1.credentials_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.credentials.v1.CreateCredentialResponse)
  })
_sym_db.RegisterMessage(CreateCredentialResponse)

_CREDENTIALSSERVICE = DESCRIPTOR.services_by_name['CredentialsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!io.strmprivacy.api.credentials.v1P\001ZKgithub.com/strmprivacy/api-definitions-go/v2/api/credentials/v1;credentials'
  _LISTCREDENTIALSREQUEST.fields_by_name['stream_ref']._options = None
  _LISTCREDENTIALSREQUEST.fields_by_name['stream_ref']._serialized_options = b'\340A\002'
  _LISTCREDENTIALSREQUEST._serialized_start=167
  _LISTCREDENTIALSREQUEST._serialized_end=256
  _LISTCREDENTIALSRESPONSE._serialized_start=258
  _LISTCREDENTIALSRESPONSE._serialized_end=346
  _DELETECREDENTIALREQUEST._serialized_start=348
  _DELETECREDENTIALREQUEST._serialized_end=392
  _DELETECREDENTIALRESPONSE._serialized_start=394
  _DELETECREDENTIALRESPONSE._serialized_end=420
  _GETCREDENTIALREQUEST._serialized_start=422
  _GETCREDENTIALREQUEST._serialized_end=463
  _GETCREDENTIALRESPONSE._serialized_start=465
  _GETCREDENTIALRESPONSE._serialized_end=550
  _CREATECREDENTIALREQUEST._serialized_start=552
  _CREATECREDENTIALREQUEST._serialized_end=637
  _CREATECREDENTIALRESPONSE._serialized_start=639
  _CREATECREDENTIALRESPONSE._serialized_end=728
  _CREDENTIALSSERVICE._serialized_start=731
  _CREDENTIALSSERVICE._serialized_end=1282
# @@protoc_insertion_point(module_scope)
